[gnome-todo] Rename to Endeavour



commit a65d5d6a943ecb1e9feaaabe42065babe5574b69
Author: Jamie Murphy <hello jamiethalacker dev>
Date:   Sat Jul 2 16:07:43 2022 -0700

    Rename to Endeavour

 .gitlab-ci.yml                                     |  2 +-
 .gitlab/issue_templates/Bug.md                     |  2 +-
 README.md                                          |  6 +--
 build-aux/flatpak/org.gnome.Todo.json              |  4 +-
 data/appdata/meson.build                           |  2 +-
 data/appdata/org.gnome.Todo.appdata.xml.in.in      |  4 +-
 data/icons/meson.build                             |  2 +-
 data/meson.build                                   |  8 ++--
 data/org.gnome.Todo.desktop.in.in                  |  4 +-
 data/org.gnome.Todo.service.in                     |  2 +-
 data/org.gnome.todo.gschema.xml                    |  6 +--
 doc/CONTRIBUTING.md                                | 12 ++---
 doc/HACKING.md                                     |  6 +--
 gnome-todo.doap => endeavour.doap                  |  2 +-
 help/C/contributing.page                           |  8 ++--
 help/C/index.page                                  |  4 +-
 help/C/overview.page                               |  2 +-
 help/C/support.page                                |  4 +-
 help/C/workflow.page                               |  2 +-
 meson.build                                        | 54 +++++++++++-----------
 src/animation/gtd-timeline.c                       |  2 +-
 src/core/gtd-activatable.c                         |  8 ++--
 src/core/gtd-manager.c                             | 12 ++---
 src/core/gtd-object.c                              |  2 +-
 src/core/gtd-plugin-manager.c                      |  2 +-
 src/core/gtd-provider.c                            |  4 +-
 src/{gnome-todo.h => endeavour.h}                  |  8 ++--
 src/gtd-debug.h.in                                 |  4 +-
 src/gui/gtd-application.c                          |  8 ++--
 src/gui/gtd-bin-layout.h                           |  2 +-
 src/gui/gtd-command-bar.h                          |  2 +-
 src/gui/gtd-initial-setup-window.ui                |  2 +-
 src/gui/gtd-notification-widget.h                  |  2 +-
 src/gui/gtd-omni-area.ui                           |  2 +-
 src/gui/gtd-star-widget.h                          |  2 +-
 src/gui/gtd-task-row.h                             |  2 +-
 src/gui/gtd-window.c                               |  4 +-
 src/gui/menus.ui                                   |  2 +-
 src/main.c                                         |  6 +--
 src/meson.build                                    | 44 +++++++++---------
 .../all-tasks-panel/all-tasks-panel-plugin.c       |  2 +-
 src/plugins/all-tasks-panel/all-tasks-panel.plugin |  2 +-
 src/plugins/all-tasks-panel/gtd-all-tasks-panel.c  |  2 +-
 src/plugins/background/background.plugin           |  4 +-
 src/plugins/background/gtd-plugin-background.c     |  8 ++--
 src/plugins/background/gtd-plugin-background.h     |  2 +-
 src/plugins/background/meson.build                 |  2 +-
 .../org.gnome.todo.background.gschema.xml          |  8 ++--
 src/plugins/background/ui/preferences.ui           |  4 +-
 ...{e-source-gnome-todo.c => e-source-endeavour.c} | 32 ++++++-------
 ...{e-source-gnome-todo.h => e-source-endeavour.h} | 10 ++--
 src/plugins/eds/eds-plugin.c                       |  2 +-
 src/plugins/eds/eds.plugin                         |  4 +-
 src/plugins/eds/gtd-plugin-eds.c                   |  2 +-
 src/plugins/eds/gtd-plugin-eds.h                   |  2 +-
 src/plugins/eds/gtd-provider-eds.h                 |  2 +-
 src/plugins/eds/gtd-provider-goa.h                 |  2 +-
 src/plugins/eds/gtd-provider-local.h               |  2 +-
 src/plugins/eds/gtd-task-eds.c                     |  6 +--
 src/plugins/eds/gtd-task-eds.h                     |  2 +-
 src/plugins/eds/gtd-task-list-eds.c                | 16 +++----
 src/plugins/eds/gtd-task-list-eds.h                |  2 +-
 src/plugins/eds/meson.build                        |  2 +-
 src/plugins/inbox-panel/gtd-inbox-panel.c          |  2 +-
 src/plugins/inbox-panel/inbox-panel-plugin.c       |  2 +-
 src/plugins/inbox-panel/inbox-panel.plugin         |  2 +-
 src/plugins/meson.build                            |  4 +-
 src/plugins/next-week-panel/gtd-next-week-panel.c  |  2 +-
 .../next-week-panel/next-week-panel-plugin.c       |  2 +-
 src/plugins/next-week-panel/next-week-panel.plugin |  2 +-
 src/plugins/peace/gtd-peace-omni-area-addin.h      |  2 +-
 src/plugins/peace/peace.plugin                     |  2 +-
 src/plugins/scheduled-panel/gtd-panel-scheduled.c  |  2 +-
 .../scheduled-panel/gtd-plugin-scheduled-panel.h   |  2 +-
 src/plugins/scheduled-panel/scheduled-panel.plugin |  2 +-
 src/plugins/task-lists-workspace/gtd-sidebar.h     |  2 +-
 .../gtd-task-lists-workspace.h                     |  2 +-
 .../task-lists-workspace-plugin.c                  |  2 +-
 .../task-lists-workspace.plugin                    |  2 +-
 src/plugins/today-panel/gtd-panel-today.c          |  2 +-
 .../today-panel/gtd-today-omni-area-addin.c        |  2 +-
 src/plugins/today-panel/today-panel-plugin.c       |  2 +-
 src/plugins/today-panel/today-panel.plugin         |  2 +-
 src/plugins/todo-txt/gtd-plugin-todo-txt.c         |  2 +-
 src/plugins/todo-txt/gtd-plugin-todo-txt.h         |  2 +-
 src/plugins/todo-txt/gtd-provider-todo-txt.c       |  2 +-
 src/plugins/todo-txt/gtd-provider-todo-txt.h       |  2 +-
 src/plugins/todo-txt/gtd-task-todo-txt.h           |  2 +-
 src/plugins/todo-txt/gtd-todo-txt-parser.h         |  2 +-
 src/plugins/todo-txt/meson.build                   |  4 +-
 .../todo-txt/org.gnome.todo.txt.gschema.xml        |  2 +-
 src/plugins/todo-txt/syntax.md                     | 14 +++---
 src/plugins/todo-txt/todo-txt.plugin.in            |  4 +-
 src/plugins/todoist/gtd-plugin-todoist.c           |  4 +-
 src/plugins/todoist/gtd-plugin-todoist.h           |  2 +-
 src/plugins/todoist/gtd-provider-todoist.c         |  4 +-
 src/plugins/todoist/gtd-provider-todoist.h         |  2 +-
 .../todoist/gtd-todoist-preferences-panel.h        |  2 +-
 src/plugins/todoist/meson.build                    |  2 +-
 src/plugins/todoist/todoist.plugin.in              |  4 +-
 src/plugins/unscheduled-panel/meson.build          |  2 +-
 .../unscheduled-panel/unscheduled-panel.plugin     |  2 +-
 .../unscheduled-panel/__init__.py                  |  4 +-
 src/plugins/welcome/gtd-welcome-workspace.h        |  2 +-
 src/plugins/welcome/welcome.plugin                 |  4 +-
 tests/dummy-provider.c                             |  2 +-
 tests/dummy-provider.h                             |  2 +-
 tests/interactive/test-animation.c                 |  2 +-
 tests/interactive/test-colorbutton.c               |  2 +-
 tests/interactive/test-filter-sort.c               |  2 +-
 tests/interactive/test-star-widget.c               |  2 +-
 tests/interactive/test-task-model.c                |  2 +-
 tests/interactive/test-widget.c                    |  2 +-
 tests/meson.build                                  |  6 +--
 tests/test-task-list.c                             |  2 +-
 tests/test-task-model.c                            |  2 +-
 116 files changed, 257 insertions(+), 257 deletions(-)
---
diff --git a/.gitlab-ci.yml b/.gitlab-ci.yml
index b721e232..2d9cdab4 100644
--- a/.gitlab-ci.yml
+++ b/.gitlab-ci.yml
@@ -21,7 +21,7 @@ flatpak:master:
         MANIFEST_PATH: "build-aux/flatpak/org.gnome.Todo.json"
         RUNTIME_REPO: "https://nightly.gnome.org/gnome-nightly.flatpakrepo";
         # Replace with your application name, as written in the manifest
-        FLATPAK_MODULE: "gnome-todo"
+        FLATPAK_MODULE: "endeavour"
         # Make sure to keep this in sync with the Flatpak manifest, all arguments
         # are passed except the config-args because we build it ourselves
         MESON_ARGS: "-Dtracing=true -Dprofile=development"
diff --git a/.gitlab/issue_templates/Bug.md b/.gitlab/issue_templates/Bug.md
index 5d080c69..c8339363 100644
--- a/.gitlab/issue_templates/Bug.md
+++ b/.gitlab/issue_templates/Bug.md
@@ -3,7 +3,7 @@ with images showing the issue.
 
 Steps to reproduce:
 
-1. Open GNOME To Do
+1. Open Endeavour
 2. Create a task
 3. ...
 
diff --git a/README.md b/README.md
index 53c29bfa..c26ef67f 100644
--- a/README.md
+++ b/README.md
@@ -1,6 +1,6 @@
-# GNOME To Do
+# Endeavour
 
-GNOME To Do is an intuitive and powerful application to manage your personal tasks. It uses GNOME
+Endeavour is an intuitive and powerful application to manage your personal tasks. It uses GNOME
 technologies and has complete integration with the GNOME desktop environment.
 
 
@@ -28,7 +28,7 @@ code.
 ## Getting In Touch
 
 We use IRC as the main form of real-time communication. Asynchronous communication happens on
-[GNOME To Do GitLab Project][gitlab]. You can join us at the [#gnome-todo][irc-channel] room on
+[Endeavour GitLab Project][gitlab]. You can join us at the [#gnome-todo][irc-channel] room on
 [GNOME IRC servers][irc-wiki-page].
 
 All communications should follow the GNOME Code of Conduct. You can read more at our
diff --git a/build-aux/flatpak/org.gnome.Todo.json b/build-aux/flatpak/org.gnome.Todo.json
index 0fa90d4a..a28a20bb 100644
--- a/build-aux/flatpak/org.gnome.Todo.json
+++ b/build-aux/flatpak/org.gnome.Todo.json
@@ -3,7 +3,7 @@
     "runtime" : "org.gnome.Platform",
     "runtime-version" : "master",
     "sdk" : "org.gnome.Sdk",
-    "command" : "gnome-todo",
+    "command" : "endeavour",
     "tags" : [
         "devel"
     ],
@@ -169,7 +169,7 @@
             ]
         },
         {
-            "name" : "gnome-todo",
+            "name" : "endeavour",
             "buildsystem" : "meson",
             "config-opts" : [
                 "-Dtracing=true",
diff --git a/data/appdata/meson.build b/data/appdata/meson.build
index 62f58bb7..21614ae2 100644
--- a/data/appdata/meson.build
+++ b/data/appdata/meson.build
@@ -10,5 +10,5 @@ appdata = i18n.merge_file(
   output: '@0  appdata xml'.format(application_id),
   po_dir: po_dir,
   install: true,
-  install_dir: join_paths(gnome_todo_datadir, 'metainfo')
+  install_dir: join_paths(endeavour_datadir, 'metainfo')
 )
diff --git a/data/appdata/org.gnome.Todo.appdata.xml.in.in b/data/appdata/org.gnome.Todo.appdata.xml.in.in
index 3c7738b7..b0d1d76f 100644
--- a/data/appdata/org.gnome.Todo.appdata.xml.in.in
+++ b/data/appdata/org.gnome.Todo.appdata.xml.in.in
@@ -4,12 +4,12 @@
   <id>@appid@</id>
   <metadata_license>CC0-1.0</metadata_license>
   <project_license>GPL-3.0+</project_license>
-  <name>To Do</name>
+  <name>Endeavour</name>
   <summary>Task manager for GNOME</summary>
 
   <description>
     <p>
-      GNOME To Do is a task management application designed to integrate with GNOME. Save and order your 
todos.
+      Endeavour is a task management application designed to integrate with GNOME. Save and order your todos.
       Manage multiple todo lists. Keep your todos on your computer or sync them with cloud providers.
       Customize your experience with plugins.
     </p>
diff --git a/data/icons/meson.build b/data/icons/meson.build
index fd79180d..7acd245d 100644
--- a/data/icons/meson.build
+++ b/data/icons/meson.build
@@ -1,4 +1,4 @@
 install_subdir(
   'hicolor',
-  install_dir: join_paths(gnome_todo_datadir, 'icons')
+  install_dir: join_paths(endeavour_datadir, 'icons')
 )
diff --git a/data/meson.build b/data/meson.build
index f8d4e414..7b2acc3f 100644
--- a/data/meson.build
+++ b/data/meson.build
@@ -11,24 +11,24 @@ desktop = i18n.merge_file(
   output: '@0@.desktop'.format(application_id),
   po_dir: po_dir,
   install: true,
-  install_dir: join_paths(gnome_todo_datadir, 'applications')
+  install_dir: join_paths(endeavour_datadir, 'applications')
 )
 
 service_conf = configuration_data()
-service_conf.set('bindir', gnome_todo_bindir)
+service_conf.set('bindir', endeavour_bindir)
 service_conf.set('application_id', application_id)
 
 service = configure_file(
   input: 'org.gnome.Todo.service.in',
   output: '@0@.service'.format(application_id),
   install: true,
-  install_dir: join_paths(gnome_todo_datadir, 'dbus-1', 'services'),
+  install_dir: join_paths(endeavour_datadir, 'dbus-1', 'services'),
   configuration: service_conf
 )
 
 install_data(
   'org.gnome.todo.gschema.xml',
-  install_dir: gnome_todo_schemadir
+  install_dir: endeavour_schemadir
 )
 
 subdir('appdata')
diff --git a/data/org.gnome.Todo.desktop.in.in b/data/org.gnome.Todo.desktop.in.in
index 86b65c6c..a357057f 100644
--- a/data/org.gnome.Todo.desktop.in.in
+++ b/data/org.gnome.Todo.desktop.in.in
@@ -1,7 +1,7 @@
 [Desktop Entry]
-Name=To Do
+Name=Endeavour
 Comment=Manage your personal tasks
-Exec=gnome-todo
+Exec=endeavour
 # Translators: Do NOT translate or transliterate this text (this is an icon file name)!
 Icon=@icon@
 Terminal=false
diff --git a/data/org.gnome.Todo.service.in b/data/org.gnome.Todo.service.in
index c367606b..8684a5bb 100644
--- a/data/org.gnome.Todo.service.in
+++ b/data/org.gnome.Todo.service.in
@@ -1,3 +1,3 @@
 [D-BUS Service]
 Name=@application_id@
-Exec=@bindir@/gnome-todo --gapplication-service
+Exec=@bindir@/endeavour --gapplication-service
diff --git a/data/org.gnome.todo.gschema.xml b/data/org.gnome.todo.gschema.xml
index a1107b08..41da5681 100644
--- a/data/org.gnome.todo.gschema.xml
+++ b/data/org.gnome.todo.gschema.xml
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<schemalist gettext-domain="gnome-todo">
+<schemalist gettext-domain="endeavour">
     <schema id="org.gnome.todo" path="/org/gnome/todo/">
         <key name="window-maximized" type="b">
             <default>true</default>
@@ -13,8 +13,8 @@
         </key>
         <key name="first-run" type="b">
             <default>true</default>
-            <summary>First run of GNOME To Do</summary>
-            <description>Whether it’s the first run of GNOME To Do (to run the initial setup) or 
not</description>
+            <summary>First run of Endeavour</summary>
+            <description>Whether it’s the first run of Endeavour (to run the initial setup) or 
not</description>
         </key>
         <key name="default-provider" type="s">
             <default>"local"</default>
diff --git a/doc/CONTRIBUTING.md b/doc/CONTRIBUTING.md
index 9dd3688e..d32deb0d 100644
--- a/doc/CONTRIBUTING.md
+++ b/doc/CONTRIBUTING.md
@@ -1,6 +1,6 @@
-# Contributing to GNOME To Do
+# Contributing to Endeavour
 
-When contributing to the development of GNOME To Do, please first discuss the change
+When contributing to the development of Endeavour, please first discuss the change
 you wish to make via issue, email, or any other method with the maintainers before
 making a change.
 
@@ -16,8 +16,8 @@ your interactions with the project.
 
 # Issues, issues and more issues!
 
-There are many ways you can contribute to GNOME To Do, and all of them involve creating issues
-in [GNOME To Do issue tracker](https://gitlab.gnome.org/GNOME/gnome-todo/issues). This is the
+There are many ways you can contribute to Endeavour, and all of them involve creating issues
+in [Endeavour issue tracker](https://gitlab.gnome.org/GNOME/gnome-todo/issues). This is the
 entry point for your contribution.
 
 To create an effective and high quality ticket, try to put the following information on your
@@ -41,7 +41,7 @@ If it's an issue, add the steps to reproduce like this:
 
 Steps to reproduce:
 
-1. Open GNOME To Do
+1. Open Endeavour
 2. Create a task
 3. ...
 
@@ -112,7 +112,7 @@ This is how it would look with a maximum width of 650px:
 
 # Code of Conduct
 
-GNOME To Do is a project developed based on GNOME Code of Conduct. You can read it below:
+Endeavour is a project developed based on GNOME Code of Conduct. You can read it below:
 
 ## Summary
 
diff --git a/doc/HACKING.md b/doc/HACKING.md
index 8c25c4dd..260e1ff9 100644
--- a/doc/HACKING.md
+++ b/doc/HACKING.md
@@ -1,13 +1,13 @@
 # Style
 
-GNOME To Do has a coding style based on GTK Coding Style, but with a few more
+Endeavour has a coding style based on GTK Coding Style, but with a few more
 rules. Please read them carefully and, if in doubt, ask a maintainer for directions.
 
 ## General
 
 The most important rule is: **see the surrounding code, and copy its style**.
 
-GNOME To Do's line length is 120 columns.
+Endeavour's line length is 120 columns.
 
 Another rule that applies to function declarations is that all parameters are
 aligned by the last '*'. There are plenty of examples below.
@@ -97,7 +97,7 @@ on_size_allocated_cb (GtkWidget     *widget,
 
 ### Line Splitting
 
-GNOME To Do's line length is 120 columns.
+Endeavour's line length is 120 columns.
 
 Line splitting works following the GTK code style, but legibility comes over above
 all. If a function call looks unbalanced following the GTK style, it is fine to
diff --git a/gnome-todo.doap b/endeavour.doap
similarity index 96%
rename from gnome-todo.doap
rename to endeavour.doap
index 663515d8..e65e2233 100644
--- a/gnome-todo.doap
+++ b/endeavour.doap
@@ -4,7 +4,7 @@
          xmlns:gnome="http://api.gnome.org/doap-extensions#";
          xmlns="http://usefulinc.com/ns/doap#";>
 
-  <name xml:lang="en">GNOME To Do</name>
+  <name xml:lang="en">Endeavour</name>
   <shortdesc xml:lang="en">Task manager for GNOME</shortdesc>
   <description>Personal task manager for GNOME</description>
   <homepage rdf:resource="https://wiki.gnome.org/Apps/Todo"; />
diff --git a/help/C/contributing.page b/help/C/contributing.page
index 8ce8646e..edcf0c07 100644
--- a/help/C/contributing.page
+++ b/help/C/contributing.page
@@ -6,12 +6,12 @@
     <link type="guide" xref="index#contribute"/>
   </info>
 
-  <title>Contribute to GNOME To do</title>
+  <title>Contribute to Endeavour</title>
 
-  <p>There are multiple ways of helping to improve GNOME To Do:</p>
+  <p>There are multiple ways of helping to improve Endeavour:</p>
   <list>
-    <item><p>File issues you have encountered while using GNOME To Do</p></item>
-    <item><p>Translate the user interface or help pages of GNOME To Do</p></item>
+    <item><p>File issues you have encountered while using Endeavour</p></item>
+    <item><p>Translate the user interface or help pages of Endeavour</p></item>
     <item><p>Correct issues or implement new features</p></item>
   </list>
 
diff --git a/help/C/index.page b/help/C/index.page
index 51b10e46..dbf90acc 100644
--- a/help/C/index.page
+++ b/help/C/index.page
@@ -4,12 +4,12 @@
       id="index">
 
   <info>
-    <desc>GNOME To Do is a simple app, with that you can create, process and manage your tasks, to raise 
your productivity. Also you can synchronize your tasks through your online accounts, so you can check them on 
all your devices.</desc>
+    <desc>Endeavour is a simple app, with that you can create, process and manage your tasks, to raise your 
productivity. Also you can synchronize your tasks through your online accounts, so you can check them on all 
your devices.</desc>
   </info>
 
   <title>
     <media type="image" its:translate="no" src="figures/org.gnome.Todo.svg" width="48" height="48"></media>
-    <span>GNOME To Do</span>
+    <span>Endeavour</span>
   </title>
 
   <p>A simple to-do app for GNOME.</p>
diff --git a/help/C/overview.page b/help/C/overview.page
index 6c1a203e..5bd1c829 100644
--- a/help/C/overview.page
+++ b/help/C/overview.page
@@ -10,6 +10,6 @@
 
 
 
-  <p>The user interface of GNOME To Do is composed of the utility pane on the left and the tasks in lists on 
the right. You can let you show your tasks in different modes. They can be selected through the utility pane. 
<gui>Inbox</gui> contains all tasks which have no date assigned to them and are not in a task list, 
<gui>Today</gui> all tasks with the date of today and <gui>Next 7 Days</gui> all tasks assigned to one of the 
next seven days. <gui>All</gui> shows all tasks in a chronological order and <gui>Archived</gui> archived 
task lists. At least there are also your custom task lists</p>
+  <p>The user interface of Endeavour is composed of the utility pane on the left and the tasks in lists on 
the right. You can let you show your tasks in different modes. They can be selected through the utility pane. 
<gui>Inbox</gui> contains all tasks which have no date assigned to them and are not in a task list, 
<gui>Today</gui> all tasks with the date of today and <gui>Next 7 Days</gui> all tasks assigned to one of the 
next seven days. <gui>All</gui> shows all tasks in a chronological order and <gui>Archived</gui> archived 
task lists. At least there are also your custom task lists</p>
 
 </page>
diff --git a/help/C/support.page b/help/C/support.page
index e06dff55..66d44941 100644
--- a/help/C/support.page
+++ b/help/C/support.page
@@ -8,8 +8,8 @@
 
   <title>Getting support</title>
 
-  <p>In the <link href="https://wiki.gnome.org/apps/todo";>wiki</link> of GNOME To Do you can read more.</p>
+  <p>In the <link href="https://wiki.gnome.org/apps/todo";>wiki</link> of Endeavour you can read more.</p>
   <p>When you have questions, ask them on <link href="https://discourse.gnome.org/tag/todo";>gnome 
discourse</link>.</p>
-  <p>You can also get in conversation with the developers of GNOME To Do by joining the <link 
href="https://gnome.element.io/#/room/#gnome-todo:gnome.org";>matrix channel</link>.</p>
+  <p>You can also get in conversation with the developers of Endeavour by joining the <link 
href="https://gnome.element.io/#/room/#gnome-todo:gnome.org";>matrix channel</link>.</p>
 
 </page>
diff --git a/help/C/workflow.page b/help/C/workflow.page
index 3538f344..93946cc9 100644
--- a/help/C/workflow.page
+++ b/help/C/workflow.page
@@ -8,7 +8,7 @@
 
   <title>Workflow</title>
 
-  <p>Managing tasks is very personal. Therefore GNOME To Do only ships with a default Workflow that can be 
altered to the needs of the user.</p>
+  <p>Managing tasks is very personal. Therefore Endeavour only ships with a default Workflow that can be 
altered to the needs of the user.</p>
 
   <section>
     <title>Task lifecycle</title>
diff --git a/meson.build b/meson.build
index 89bc9534..6761446a 100644
--- a/meson.build
+++ b/meson.build
@@ -1,5 +1,5 @@
 project(
-     'gnome-todo',
+     'endeavour',
               'c',
           version: '42.alpha',
           license: 'GPL3+',
@@ -7,33 +7,33 @@ project(
     meson_version: '>= 0.53.0'
 )
 
-gnome_todo_version = meson.project_version()
+endeavour_version = meson.project_version()
 
-gnome_todo_gir_namespace = 'Gtd'
-gnome_todo_gir_version = '1.0'
+endeavour_gir_namespace = 'Gtd'
+endeavour_gir_version = '1.0'
 
-gnome_todo_prefix = get_option('prefix')
-gnome_todo_bindir = join_paths(gnome_todo_prefix, get_option('bindir'))
-gnome_todo_datadir = join_paths(gnome_todo_prefix, get_option('datadir'))
-gnome_todo_includedir = join_paths(gnome_todo_prefix, get_option('includedir'))
-gnome_todo_libdir = join_paths(gnome_todo_prefix, get_option('libdir'))
-gnome_todo_libexecdir = join_paths(gnome_todo_prefix, get_option('libexecdir'))
-gnome_todo_localedir = join_paths(gnome_todo_prefix, get_option('localedir'))
+endeavour_prefix = get_option('prefix')
+endeavour_bindir = join_paths(endeavour_prefix, get_option('bindir'))
+endeavour_datadir = join_paths(endeavour_prefix, get_option('datadir'))
+endeavour_includedir = join_paths(endeavour_prefix, get_option('includedir'))
+endeavour_libdir = join_paths(endeavour_prefix, get_option('libdir'))
+endeavour_libexecdir = join_paths(endeavour_prefix, get_option('libexecdir'))
+endeavour_localedir = join_paths(endeavour_prefix, get_option('localedir'))
 
-gnome_todo_pkgdatadir = join_paths(gnome_todo_datadir, meson.project_name())
-gnome_todo_pkgincludedir = join_paths(gnome_todo_includedir, meson.project_name())
-gnome_todo_pkglibdir = join_paths(gnome_todo_libdir, meson.project_name())
+endeavour_pkgdatadir = join_paths(endeavour_datadir, meson.project_name())
+endeavour_pkgincludedir = join_paths(endeavour_includedir, meson.project_name())
+endeavour_pkglibdir = join_paths(endeavour_libdir, meson.project_name())
 
-gnome_todo_pluginsdir = join_paths(gnome_todo_pkglibdir, 'plugins')
-gnome_todo_schemadir = join_paths(gnome_todo_datadir, 'glib-2.0', 'schemas')
+endeavour_pluginsdir = join_paths(endeavour_pkglibdir, 'plugins')
+endeavour_schemadir = join_paths(endeavour_datadir, 'glib-2.0', 'schemas')
 
 soversion = 0
 current = 0
 revision = 0
 libversion = '@0@.@1@.@2@'.format(soversion, current, revision)
 
-gnome_todo_debug = get_option('buildtype').contains('debug')
-gnome_todo_tracing = get_option('tracing')
+endeavour_debug = get_option('buildtype').contains('debug')
+endeavour_tracing = get_option('tracing')
 
 cc = meson.get_compiler('c')
 
@@ -54,9 +54,9 @@ config_h.set_quoted('GETTEXT_PACKAGE', meson.project_name())
 config_h.set('DEVELOPMENT_BUILD', profile == 'Devel')
 
 # debug options
-config_h.set('GNOME_TODO_ENABLE_DEBUG', gnome_todo_debug)
-config_h.set('ENABLE_TRACING', gnome_todo_tracing)
-config_h.set('NDEBUG', not gnome_todo_debug)
+config_h.set('ENDEAVOUR_ENABLE_DEBUG', endeavour_debug)
+config_h.set('ENABLE_TRACING', endeavour_tracing)
+config_h.set('NDEBUG', not endeavour_debug)
 
 # package
 set_defines = [
@@ -65,7 +65,7 @@ set_defines = [
   ['PACKAGE', meson.project_name()],
   ['PACKAGE_BUGREPORT', 'https://gitlab.gnome.org/GNOME/' + meson.project_name() + '/issues/new'],
   ['PACKAGE_NAME', meson.project_name()],
-  ['PACKAGE_STRING', '@0@ @1@'.format(meson.project_name(), gnome_todo_version)],
+  ['PACKAGE_STRING', '@0@ @1@'.format(meson.project_name(), endeavour_version)],
   ['PACKAGE_TARNAME', meson.project_name()],
   ['PACKAGE_URL', 'https://wiki.gnome.org/Apps/Todo'],
   ['PACKAGE_VERSION', meson.project_version()],
@@ -120,7 +120,7 @@ endforeach
 common_flags = ['-DHAVE_CONFIG_H']
 compiler_flags = []
 
-if gnome_todo_debug
+if endeavour_debug
   test_cflags = [
     '-Wall',
     '-Wextra',
@@ -146,7 +146,7 @@ glib_dep = dependency('glib-2.0', version: '>= 2.58.0')
 gtk_dep = dependency('gtk4', version: '>= 3.92.0')
 libadwaita_dep = dependency('libadwaita-1', fallback: ['libadwaita', 'libadwaita_dep'])
 
-gnome_todo_deps = [
+endeavour_deps = [
   glib_dep,
   gtk_dep,
   libadwaita_dep,
@@ -175,12 +175,12 @@ subdir('help')
 
 summary({
   'Source': meson.source_root(),
-  'Prefix': gnome_todo_prefix,
+  'Prefix': endeavour_prefix,
 })
 
 summary({
-  'Debug': gnome_todo_debug,
-  'Tracing': gnome_todo_tracing,
+  'Debug': endeavour_debug,
+  'Tracing': endeavour_tracing,
 }, section: 'Development')
 
 summary({
diff --git a/src/animation/gtd-timeline.c b/src/animation/gtd-timeline.c
index 9ec77f0e..da16fd9a 100644
--- a/src/animation/gtd-timeline.c
+++ b/src/animation/gtd-timeline.c
@@ -78,7 +78,7 @@
 #include "gtd-timeline.h"
 
 #include "gtd-debug.h"
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 typedef struct
 {
diff --git a/src/core/gtd-activatable.c b/src/core/gtd-activatable.c
index bf71ba03..fcfd60e0 100644
--- a/src/core/gtd-activatable.c
+++ b/src/core/gtd-activatable.c
@@ -29,18 +29,18 @@
  * @stability:Unstable
  *
  * The #GtdActivatable interface is the interface plugins must
- * implement in order to be seen by GNOME To Do.
+ * implement in order to be seen by Endeavour.
  *
  * When plugins are loaded, the gtd_activatable_activate() vfunc
- * is called. Use this vfunc to load anything that depends on GNOME
- * To Do.
+ * is called. Use this vfunc to load anything that depends on
+ * Endeavour.
  *
  * When plugins are unloaded, the gtd_activatable_deactivate() vfunc
  * if called. Ideally, the implementation should undo everything that
  * was done on gtd_activatable_activate().
  *
  * A plugin implementation may expose one or more #GtdProvider instances,
- * which are the data sources of GNOME To Do. See the 'eds' plugin for
+ * which are the data sources of Endeavour. See the 'eds' plugin for
  * a reference on how to expose one ('local') and multiple (Online Accounts)
  * providers.
  *
diff --git a/src/core/gtd-manager.c b/src/core/gtd-manager.c
index cf1515ae..87c77646 100644
--- a/src/core/gtd-manager.c
+++ b/src/core/gtd-manager.c
@@ -37,17 +37,17 @@
 
 /**
  * SECTION:gtd-manager
- * @short_description:bridge between plugins and GNOME To Do
+ * @short_description:bridge between plugins and Endeavour
  * @title:GtdManager
  * @stability:Unstable
  * @see_also:#GtdNotification,#GtdActivatable
  *
  * The #GtdManager object is a singleton object that exposes all the data
- * inside the plugin to GNOME To Do, and vice-versa. From here, plugins have
+ * inside the plugin to Endeavour, and vice-versa. From here, plugins have
  * access to all the tasklists, tasks and panels of the other plugins.
  *
- * Objects can use gtd_manager_emit_error_message() to send errors to GNOME
- * To Do. This will create a #GtdNotification internally.
+ * Objects can use gtd_manager_emit_error_message() to send errors to
+ * Endeavour. This will create a #GtdNotification internally.
  */
 
 struct _GtdManager
@@ -337,7 +337,7 @@ gtd_manager_class_init (GtdManagerClass *klass)
   /**
    * GtdManager::clock:
    *
-   * The underlying clock of GNOME To Do.
+   * The underlying clock of Endeavour.
    */
   g_object_class_install_property (
         object_class,
@@ -729,7 +729,7 @@ gtd_manager_get_settings (GtdManager *self)
  *
  * Retrieves the 'first-run' setting.
  *
- * Returns: %TRUE if GNOME To Do was never run before, %FALSE otherwise.
+ * Returns: %TRUE if Endeavour was never run before, %FALSE otherwise.
  */
 gboolean
 gtd_manager_get_is_first_run (GtdManager *self)
diff --git a/src/core/gtd-object.c b/src/core/gtd-object.c
index beb506bc..c1157fc5 100644
--- a/src/core/gtd-object.c
+++ b/src/core/gtd-object.c
@@ -27,7 +27,7 @@
  * @Short_description: base class for loadable and uniquely identifiable objects
  * @Title: GtdObject
  *
- * #GtdObject is the base class of many object in GNOME To Do, and it useful for
+ * #GtdObject is the base class of many object in Endeavour, and it useful for
  * when a given object is loadable and/or uniquely identifiable. Some examples of
  * it are #GtdTask, #GtdTaskList and #GtdNotification.
  *
diff --git a/src/core/gtd-plugin-manager.c b/src/core/gtd-plugin-manager.c
index e8536922..e2b651fd 100644
--- a/src/core/gtd-plugin-manager.c
+++ b/src/core/gtd-plugin-manager.c
@@ -225,7 +225,7 @@ setup_engine (GtdPluginManager *self)
   plugin_dir = g_build_filename (g_get_home_dir (),
                                  ".local",
                                  "lib",
-                                 "gnome-todo",
+                                 "endeavour",
                                  "plugins",
                                  NULL);
 
diff --git a/src/core/gtd-provider.c b/src/core/gtd-provider.c
index cdbe634b..60ed85ff 100644
--- a/src/core/gtd-provider.c
+++ b/src/core/gtd-provider.c
@@ -25,11 +25,11 @@
 
 /**
  * SECTION:gtd-provider
- * @short_description:data sources for GNOME To do
+ * @short_description:data sources for Endeavour
  * @title: GtdProvider
  * @stability:Unstable
  *
- * The #GtdProvider is the interface that GNOME To Do uses to
+ * The #GtdProvider is the interface that Endeavour uses to
  * connect to data sources. It must provide ways to create, update
  * and remove tasks and tasklists.
  *
diff --git a/src/gnome-todo.h b/src/endeavour.h
similarity index 95%
rename from src/gnome-todo.h
rename to src/endeavour.h
index bd3b7b32..aa93aa96 100644
--- a/src/gnome-todo.h
+++ b/src/endeavour.h
@@ -1,4 +1,4 @@
-/* gnome-todo.h
+/* endeavour.h
  *
  * Copyright (C) 2015-2020 Georges Basile Stavracas Neto <georges stavracas gmail com>
  *
@@ -16,8 +16,8 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef GNOME_TODO_H
-#define GNOME_TODO_H
+#ifndef ENDEAVOUR_H
+#define ENDEAVOUR_H
 
 #include <libpeas/peas.h>
 
@@ -53,4 +53,4 @@
 #include "gtd-window.h"
 #include "gtd-workspace.h"
 
-#endif /* GNOME_TODO_H */
+#endif /* ENDEAVOUR_H */
diff --git a/src/gtd-debug.h.in b/src/gtd-debug.h.in
index 2228c6fc..ba5bcf84 100644
--- a/src/gtd-debug.h.in
+++ b/src/gtd-debug.h.in
@@ -27,7 +27,7 @@
  * @stability:stable
  *
  * Macros used for tracing and debugging code. These
- * are only valid when To Do is compiled with tracing
+ * are only valid when Endeavour is compiled with tracing
  * support (pass `--enable-tracing` to the configure
  * script to do that).
  */
@@ -204,7 +204,7 @@ G_BEGIN_DECLS
 #define _GTD_BUG(Component, Description, File, Line, Func, ...)                        \
   G_STMT_START {                                                                        \
     g_printerr ("-----------------------------------------------------------------\n"); \
-    g_printerr ("You've found a bug in To Do or one of its dependent libraries.\n");    \
+    g_printerr ("You've found a bug in Endeavour or one of its dependent libraries.\n");    \
     g_printerr ("Please help us help you by filing a bug report at:\n");                \
     g_printerr ("\n");                                                                  \
     g_printerr ("@BUGREPORT_URL@&component=%s\n", Component);                           \
diff --git a/src/gui/gtd-application.c b/src/gui/gtd-application.c
index b9622af0..497bae34 100644
--- a/src/gui/gtd-application.c
+++ b/src/gui/gtd-application.c
@@ -70,7 +70,7 @@ static void           gtd_application_show_help                        (GSimpleA
 G_DEFINE_TYPE (GtdApplication, gtd_application, ADW_TYPE_APPLICATION)
 
 static GOptionEntry cmd_options[] = {
-  { "quit", 'q', 0, G_OPTION_ARG_NONE, NULL, N_("Quit GNOME To Do"), NULL },
+  { "quit", 'q', 0, G_OPTION_ARG_NONE, NULL, N_("Quit Endeavour"), NULL },
   { "debug", 'd', 0, G_OPTION_ARG_NONE, NULL, N_("Enable debug messages"), NULL },
   { NULL }
 };
@@ -128,9 +128,9 @@ gtd_application_show_about (GSimpleAction *simple,
   self = GTD_APPLICATION (user_data);
 
   gtk_show_about_dialog (GTK_WINDOW (self->window),
-                         "program-name", _("To Do"),
+                         "program-name", _("Endeavour"),
                          "version", GTD_VCS_TAG,
-                         "copyright", _("Copyright \xC2\xA9 2015–2020 The To Do authors"),
+                         "copyright", _("Copyright \xC2\xA9 2015–2020 The Endeavour authors"),
                          "license-type", GTK_LICENSE_GPL_3_0,
                          "authors", authors,
                          "artists", artists,
@@ -155,7 +155,7 @@ gtd_application_show_help (GSimpleAction *simple,
                            gpointer       user_data)
 {
   GtdApplication *self = GTD_APPLICATION (user_data);
-  gtk_show_uri (GTK_WINDOW (self->window) , "help:gnome-todo", GDK_CURRENT_TIME);
+  gtk_show_uri (GTK_WINDOW (self->window) , "help:endeavour", GDK_CURRENT_TIME);
 }
 
 GtdApplication *
diff --git a/src/gui/gtd-bin-layout.h b/src/gui/gtd-bin-layout.h
index fe40a44f..8d66ead1 100644
--- a/src/gui/gtd-bin-layout.h
+++ b/src/gui/gtd-bin-layout.h
@@ -20,7 +20,7 @@
 
 #pragma once
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 G_BEGIN_DECLS
 
diff --git a/src/gui/gtd-command-bar.h b/src/gui/gtd-command-bar.h
index 9fc21358..2ab17304 100644
--- a/src/gui/gtd-command-bar.h
+++ b/src/gui/gtd-command-bar.h
@@ -20,7 +20,7 @@
 
 #pragma once
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 G_BEGIN_DECLS
 
diff --git a/src/gui/gtd-initial-setup-window.ui b/src/gui/gtd-initial-setup-window.ui
index 4f9a522b..01c4b873 100644
--- a/src/gui/gtd-initial-setup-window.ui
+++ b/src/gui/gtd-initial-setup-window.ui
@@ -50,7 +50,7 @@
     </child>
     <child type="titlebar">
       <object class="GtkHeaderBar" id="headerbar">
-        <property name="title" translatable="yes">To Do Setup</property>
+        <property name="title" translatable="yes">Endeavour Setup</property>
         <child>
           <object class="GtkButton" id="cancel_button">
             <property name="label" translatable="yes">_Cancel</property>
diff --git a/src/gui/gtd-notification-widget.h b/src/gui/gtd-notification-widget.h
index 032edb8e..b2013edb 100644
--- a/src/gui/gtd-notification-widget.h
+++ b/src/gui/gtd-notification-widget.h
@@ -19,7 +19,7 @@
 #ifndef GTD_NOTIFICATION_WIDGET_H
 #define GTD_NOTIFICATION_WIDGET_H
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 G_BEGIN_DECLS
 
diff --git a/src/gui/gtd-omni-area.ui b/src/gui/gtd-omni-area.ui
index ea79f1fa..5026e2c8 100644
--- a/src/gui/gtd-omni-area.ui
+++ b/src/gui/gtd-omni-area.ui
@@ -41,7 +41,7 @@
                         <property name="name">placeholder</property>
                         <property name="child">
                           <object class="GtkLabel">
-                            <property name="label" translatable="yes">To Do</property>
+                            <property name="label" translatable="yes">Endeavour</property>
                             <property name="xalign">0.0</property>
                           </object>
                         </property>
diff --git a/src/gui/gtd-star-widget.h b/src/gui/gtd-star-widget.h
index 3c3b9fa1..6f93b44f 100644
--- a/src/gui/gtd-star-widget.h
+++ b/src/gui/gtd-star-widget.h
@@ -20,7 +20,7 @@
 
 #pragma once
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 G_BEGIN_DECLS
 
diff --git a/src/gui/gtd-task-row.h b/src/gui/gtd-task-row.h
index cb1648be..111fec30 100644
--- a/src/gui/gtd-task-row.h
+++ b/src/gui/gtd-task-row.h
@@ -19,7 +19,7 @@
 #ifndef GTD_TASK_ROW_H
 #define GTD_TASK_ROW_H
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 G_BEGIN_DECLS
 
diff --git a/src/gui/menus.ui b/src/gui/menus.ui
index 99e29b32..0e486a30 100644
--- a/src/gui/menus.ui
+++ b/src/gui/menus.ui
@@ -14,7 +14,7 @@
         <attribute name="action">app.help</attribute>
       </item>
       <item>
-        <attribute name="label" translatable="yes">_About To Do</attribute>
+        <attribute name="label" translatable="yes">_About Endeavour</attribute>
         <attribute name="action">app.about</attribute>
       </item>
     </section>
diff --git a/src/meson.build b/src/meson.build
index ebafc5fd..cf6dc257 100644
--- a/src/meson.build
+++ b/src/meson.build
@@ -14,7 +14,7 @@ vcs_tag = vcs_tag(
 
 vcs_identifier_h = declare_dependency(sources: vcs_tag)
 
-gnome_todo_deps += vcs_identifier_h
+endeavour_deps += vcs_identifier_h
 
 ###########
 # Plugins #
@@ -38,7 +38,7 @@ subdir('plugins')
 # Dependencies #
 ################
 
-gtd_deps = gnome_todo_deps + [
+gtd_deps = endeavour_deps + [
   plugins_dep,
 ]
 
@@ -98,7 +98,7 @@ headers = files(
   'models/gtd-list-store.h',
   'gtd-types.h',
   'gtd-utils.h',
-  'gnome-todo.h'
+  'endeavour.h'
 )
 
 install_headers(headers, subdir: meson.project_name())
@@ -184,11 +184,11 @@ sources += gnome.compile_resources(
 )
 
 cflags = [
-  '-DPACKAGE_DATA_DIR="@0@"'.format(gnome_todo_pkgdatadir),
-  '-DPACKAGE_LIB_DIR="@0@"'.format(gnome_todo_pkglibdir),
-  '-DPACKAGE_LOCALE_DIR="@0@"'.format(gnome_todo_localedir),
+  '-DPACKAGE_DATA_DIR="@0@"'.format(endeavour_pkgdatadir),
+  '-DPACKAGE_LIB_DIR="@0@"'.format(endeavour_pkglibdir),
+  '-DPACKAGE_LOCALE_DIR="@0@"'.format(endeavour_localedir),
   '-DPACKAGE_SRC_DIR="@0@"'.format(meson.current_source_dir()),
-  '-DUI_DATA_DIR="@0@"'.format(join_paths(gnome_todo_pkgdatadir, 'style'))
+  '-DUI_DATA_DIR="@0@"'.format(join_paths(endeavour_pkgdatadir, 'style'))
 ]
 
 ldflags = [ '-Wl,--export-dynamic' ]
@@ -200,7 +200,7 @@ ldflags = [ '-Wl,--export-dynamic' ]
 
 debug_conf = configuration_data()
 debug_conf.set('BUGREPORT_URL', 'https://gitlab.gnome.org/GNOME/gnome-todo/issues/new')
-debug_conf.set10('ENABLE_TRACING', gnome_todo_tracing)
+debug_conf.set10('ENABLE_TRACING', endeavour_tracing)
 
 
 sources += configure_file(
@@ -211,10 +211,10 @@ sources += configure_file(
 
 
 ##############
-# gnome-todo #
+# endeavour #
 ##############
 
-gnome_todo = executable(
+endeavour = executable(
   meson.project_name(),
                sources,
   include_directories: incs,
@@ -222,7 +222,7 @@ gnome_todo = executable(
                c_args: cflags,
             link_args: ldflags,
               install: true,
-          install_dir: gnome_todo_bindir
+          install_dir: endeavour_bindir
 )
 
 
@@ -252,13 +252,13 @@ libgtd_dep = declare_dependency(
 
 pkg.generate(
     libraries: libgtd,
-      version: gnome_todo_version,
-         name: 'GNOME To Do',
-  description: 'Header and path for GNOME Todo Plugins',
+      version: endeavour_version,
+         name: 'Endeavour',
+  description: 'Header and path for Endeavour Plugins',
      filebase: meson.project_name(),
       subdirs: meson.project_name(),
-    variables: 'exec_prefix=' + gnome_todo_libexecdir,
-  install_dir: join_paths(gnome_todo_libdir, 'pkgconfig')
+    variables: 'exec_prefix=' + endeavour_libexecdir,
+  install_dir: join_paths(endeavour_libdir, 'pkgconfig')
 )
 
 
@@ -323,16 +323,16 @@ if get_option('introspection')
 
   gir_extra_args = '--warn-all'
 
-  gir_dir = join_paths(gnome_todo_datadir, '@0@-@1@'.format('gir', gnome_todo_gir_version))
-  typelib_dir = join_paths(gnome_todo_libdir, '@0@-@1@'.format('girepository', gnome_todo_gir_version))
+  gir_dir = join_paths(endeavour_datadir, '@0@-@1@'.format('gir', endeavour_gir_version))
+  typelib_dir = join_paths(endeavour_libdir, '@0@-@1@'.format('girepository', endeavour_gir_version))
 
   gnome.generate_gir(
                  libgtd,
                 sources: gir_sources,
-              namespace: gnome_todo_gir_namespace,
-              nsversion: gnome_todo_gir_version,
-      identifier_prefix: gnome_todo_gir_namespace,
-          symbol_prefix: gnome_todo_gir_namespace.to_lower(),
+              namespace: endeavour_gir_namespace,
+              nsversion: endeavour_gir_version,
+      identifier_prefix: endeavour_gir_namespace,
+          symbol_prefix: endeavour_gir_namespace.to_lower(),
                includes: gir_incs,
     include_directories: incs,
              extra_args: gir_extra_args,
diff --git a/src/plugins/all-tasks-panel/all-tasks-panel-plugin.c 
b/src/plugins/all-tasks-panel/all-tasks-panel-plugin.c
index 5ee037bd..93aedfef 100644
--- a/src/plugins/all-tasks-panel/all-tasks-panel-plugin.c
+++ b/src/plugins/all-tasks-panel/all-tasks-panel-plugin.c
@@ -21,7 +21,7 @@
 
 #define G_LOG_DOMAIN "GtdPluginAllTasksPanel"
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include "gtd-all-tasks-panel.h"
 
diff --git a/src/plugins/all-tasks-panel/all-tasks-panel.plugin 
b/src/plugins/all-tasks-panel/all-tasks-panel.plugin
index 01707d29..ac184ca0 100644
--- a/src/plugins/all-tasks-panel/all-tasks-panel.plugin
+++ b/src/plugins/all-tasks-panel/all-tasks-panel.plugin
@@ -4,7 +4,7 @@ Module = all-tasks-panel
 Description = A panel to show all open tasks
 Version = @VERSION@
 Authors = Georges Basile Stavracas Neto <gbsneto gnome org>
-Copyright = Copyleft © The To Do maintainers
+Copyright = Copyleft © The Endeavour maintainers
 Website = https://wiki.gnome.org/Apps/Todo
 Builtin = true
 License = GPL
diff --git a/src/plugins/all-tasks-panel/gtd-all-tasks-panel.c 
b/src/plugins/all-tasks-panel/gtd-all-tasks-panel.c
index 182eeee4..9812b9fe 100644
--- a/src/plugins/all-tasks-panel/gtd-all-tasks-panel.c
+++ b/src/plugins/all-tasks-panel/gtd-all-tasks-panel.c
@@ -23,7 +23,7 @@
 
 #include "gtd-all-tasks-panel.h"
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include "gtd-debug.h"
 
diff --git a/src/plugins/background/background.plugin b/src/plugins/background/background.plugin
index 3aaebdb9..0d827270 100644
--- a/src/plugins/background/background.plugin
+++ b/src/plugins/background/background.plugin
@@ -1,10 +1,10 @@
 [Plugin]
 Name = Run in background
 Module = background
-Description = Let GNOME To Do run in background and send notifications
+Description = Let Endeavour run in background and send notifications
 Version = @VERSION@
 Authors = Georges Basile Stavracas Neto <gbsneto gnome org>
-Copyright = Copyleft © The To Do maintainers
+Copyright = Copyleft © The Endeavour maintainers
 Website = https://wiki.gnome.org/Apps/Todo
 Builtin = true
 License = GPL
diff --git a/src/plugins/background/gtd-plugin-background.h b/src/plugins/background/gtd-plugin-background.h
index 40b292d2..2b7f323b 100644
--- a/src/plugins/background/gtd-plugin-background.h
+++ b/src/plugins/background/gtd-plugin-background.h
@@ -19,7 +19,7 @@
 #ifndef GTD_PLUGIN_BACKGROUND_H
 #define GTD_PLUGIN_BACKGROUND_H
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include <glib.h>
 
diff --git a/src/plugins/background/meson.build b/src/plugins/background/meson.build
index 59d3635f..b1ccb224 100644
--- a/src/plugins/background/meson.build
+++ b/src/plugins/background/meson.build
@@ -16,5 +16,5 @@ plugins_sources += gnome.compile_resources(
 
 install_data(
   'org.gnome.todo.background.gschema.xml',
-  install_dir: gnome_todo_schemadir
+  install_dir: endeavour_schemadir
 )
diff --git a/src/plugins/background/org.gnome.todo.background.gschema.xml 
b/src/plugins/background/org.gnome.todo.background.gschema.xml
index 5adf4bd2..af783015 100644
--- a/src/plugins/background/org.gnome.todo.background.gschema.xml
+++ b/src/plugins/background/org.gnome.todo.background.gschema.xml
@@ -1,15 +1,15 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<schemalist gettext-domain="gnome-todo">
+<schemalist gettext-domain="endeavour">
     <schema id="org.gnome.todo.plugins.background" path="/org/gnome/todo/plugins/background/">
         <key name="run-on-startup" type="b">
             <default>false</default>
-            <summary>Run To Do on startup</summary>
-            <description>Whether GNOME To Do should run on startup</description>
+            <summary>Run Endeavour on startup</summary>
+            <description>Whether Endeavour should run on startup</description>
         </key>
         <key name="show-notifications" type="b">
             <default>true</default>
             <summary>Show notifications on startup</summary>
-            <description>Whether GNOME To Do should show notifications or not</description>
+            <description>Whether Endeavour should show notifications or not</description>
         </key>
     </schema>
 </schemalist>
diff --git a/src/plugins/background/ui/preferences.ui b/src/plugins/background/ui/preferences.ui
index b3224dc7..91fb61a4 100644
--- a/src/plugins/background/ui/preferences.ui
+++ b/src/plugins/background/ui/preferences.ui
@@ -49,7 +49,7 @@
                     <child>
                       <object class="GtkLabel">
                         <property name="hexpand">1</property>
-                        <property name="label" translatable="yes">Run To Do automatically when you log 
in</property>
+                        <property name="label" translatable="yes">Run Endeavour automatically when you log 
in</property>
                         <property name="xalign">0</property>
                         <style>
                           <class name="dim-label"/>
@@ -109,7 +109,7 @@
                     <child>
                       <object class="GtkLabel">
                         <property name="hexpand">1</property>
-                        <property name="label" translatable="yes">When To Do runs, show a startup 
notification</property>
+                        <property name="label" translatable="yes">When Endeavour runs, show a startup 
notification</property>
                         <property name="xalign">0</property>
                         <style>
                           <class name="dim-label"/>
diff --git a/src/plugins/eds/e-source-gnome-todo.c b/src/plugins/eds/e-source-endeavour.c
similarity index 76%
rename from src/plugins/eds/e-source-gnome-todo.c
rename to src/plugins/eds/e-source-endeavour.c
index 09634d13..3ca88463 100644
--- a/src/plugins/eds/e-source-gnome-todo.c
+++ b/src/plugins/eds/e-source-endeavour.c
@@ -16,16 +16,16 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "e-source-gnome-todo.h"
+#include "e-source-endeavour.h"
 
-struct _ESourceGnomeTodo
+struct _ESourceEndeavour
 {
   ESourceExtension    parent;
 
   guint               api_version;
 };
 
-G_DEFINE_TYPE (ESourceGnomeTodo, e_source_gnome_todo, E_TYPE_SOURCE_EXTENSION)
+G_DEFINE_TYPE (ESourceEndeavour, e_source_endeavour, E_TYPE_SOURCE_EXTENSION)
 
 enum
 {
@@ -42,12 +42,12 @@ static GParamSpec *properties [N_PROPS] = { NULL, };
  */
 
 static void
-e_source_gnome_todo_get_property (GObject    *object,
+e_source_endeavour_get_property (GObject    *object,
                                   guint       prop_id,
                                   GValue     *value,
                                   GParamSpec *pspec)
 {
-  ESourceGnomeTodo *self = E_SOURCE_GNOME_TODO (object);
+  ESourceEndeavour *self = E_SOURCE_ENDEAVOUR (object);
 
   switch (prop_id)
     {
@@ -61,12 +61,12 @@ e_source_gnome_todo_get_property (GObject    *object,
 }
 
 static void
-e_source_gnome_todo_set_property (GObject      *object,
+e_source_endeavour_set_property (GObject      *object,
                                   guint         prop_id,
                                   const GValue *value,
                                   GParamSpec   *pspec)
 {
-  ESourceGnomeTodo *self = E_SOURCE_GNOME_TODO (object);
+  ESourceEndeavour *self = E_SOURCE_ENDEAVOUR (object);
 
   switch (prop_id)
     {
@@ -80,15 +80,15 @@ e_source_gnome_todo_set_property (GObject      *object,
 }
 
 static void
-e_source_gnome_todo_class_init (ESourceGnomeTodoClass *klass)
+e_source_endeavour_class_init (ESourceEndeavourClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   ESourceExtensionClass *extension_class = E_SOURCE_EXTENSION_CLASS (klass);
 
-  object_class->get_property = e_source_gnome_todo_get_property;
-  object_class->set_property = e_source_gnome_todo_set_property;
+  object_class->get_property = e_source_endeavour_get_property;
+  object_class->set_property = e_source_endeavour_set_property;
 
-  extension_class->name = E_SOURCE_EXTENSION_GNOME_TODO;
+  extension_class->name = E_SOURCE_EXTENSION_ENDEAVOUR;
 
   properties[PROP_API_VERSION] = g_param_spec_uint ("api-version",
                                                     "API Version",
@@ -101,24 +101,24 @@ e_source_gnome_todo_class_init (ESourceGnomeTodoClass *klass)
 }
 
 static void
-e_source_gnome_todo_init (ESourceGnomeTodo *self)
+e_source_endeavour_init (ESourceEndeavour *self)
 {
   self->api_version = 0;
 }
 
 guint
-e_source_gnome_todo_get_api_version (ESourceGnomeTodo *self)
+e_source_endeavour_get_api_version (ESourceEndeavour *self)
 {
-  g_return_val_if_fail (E_IS_SOURCE_GNOME_TODO (self), 0);
+  g_return_val_if_fail (E_IS_SOURCE_ENDEAVOUR (self), 0);
 
   return self->api_version;
 }
 
 void
-e_source_gnome_todo_set_api_version (ESourceGnomeTodo *self,
+e_source_endeavour_set_api_version (ESourceEndeavour *self,
                                      guint             api_version)
 {
-  g_return_if_fail (E_IS_SOURCE_GNOME_TODO (self));
+  g_return_if_fail (E_IS_SOURCE_ENDEAVOUR (self));
 
   e_source_extension_property_lock (E_SOURCE_EXTENSION (self));
   self->api_version = api_version;
diff --git a/src/plugins/eds/e-source-gnome-todo.h b/src/plugins/eds/e-source-endeavour.h
similarity index 69%
rename from src/plugins/eds/e-source-gnome-todo.h
rename to src/plugins/eds/e-source-endeavour.h
index 629603b2..ca70c18d 100644
--- a/src/plugins/eds/e-source-gnome-todo.h
+++ b/src/plugins/eds/e-source-endeavour.h
@@ -22,14 +22,14 @@
 
 G_BEGIN_DECLS
 
-#define E_SOURCE_EXTENSION_GNOME_TODO "GNOME To Do"
+#define E_SOURCE_EXTENSION_ENDEAVOUR "Endeavour"
 
-#define E_TYPE_SOURCE_GNOME_TODO (e_source_gnome_todo_get_type())
-G_DECLARE_FINAL_TYPE (ESourceGnomeTodo, e_source_gnome_todo, E, SOURCE_GNOME_TODO, ESourceExtension)
+#define E_TYPE_SOURCE_ENDEAVOUR (e_source_endeavour_get_type())
+G_DECLARE_FINAL_TYPE (ESourceEndeavour, e_source_endeavour, E, SOURCE_ENDEAVOUR, ESourceExtension)
 
-guint                e_source_gnome_todo_get_api_version         (ESourceGnomeTodo   *self);
+guint                e_source_endeavour_get_api_version         (ESourceEndeavour   *self);
 
-void                 e_source_gnome_todo_set_api_version         (ESourceGnomeTodo   *self,
+void                 e_source_endeavour_set_api_version         (ESourceEndeavour   *self,
                                                                   guint               api_version);
 
 G_END_DECLS
diff --git a/src/plugins/eds/eds-plugin.c b/src/plugins/eds/eds-plugin.c
index d2e994c1..df172d0c 100644
--- a/src/plugins/eds/eds-plugin.c
+++ b/src/plugins/eds/eds-plugin.c
@@ -18,7 +18,7 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 #include "gtd-plugin-eds.h"
 
 G_MODULE_EXPORT void
diff --git a/src/plugins/eds/eds.plugin b/src/plugins/eds/eds.plugin
index 530c4592..b7f28cfd 100644
--- a/src/plugins/eds/eds.plugin
+++ b/src/plugins/eds/eds.plugin
@@ -1,10 +1,10 @@
 [Plugin]
 Name = Core
 Module = eds
-Description = Evolution-data-server plugin for GNOME To Do
+Description = Evolution-data-server plugin for Endeavour
 Version = @VERSION@
 Authors = Georges Basile Stavracas Neto <gbsneto gnome org>
-Copyright = Copyleft © The To Do maintainers
+Copyright = Copyleft © The Endeavour maintainers
 Website = https://wiki.gnome.org/Apps/Todo
 Builtin = true
 Hidden = true
diff --git a/src/plugins/eds/gtd-plugin-eds.c b/src/plugins/eds/gtd-plugin-eds.c
index a04889ff..62009163 100644
--- a/src/plugins/eds/gtd-plugin-eds.c
+++ b/src/plugins/eds/gtd-plugin-eds.c
@@ -27,7 +27,7 @@
 
 /**
  * The #GtdPluginEds is a class that loads all the
- * essential providers of GNOME To Do.
+ * essential providers of Endeavour.
  *
  * It basically loads #ESourceRegistry which provides
  * #GtdProviderLocal. Immediately after that, it loads
diff --git a/src/plugins/eds/gtd-plugin-eds.h b/src/plugins/eds/gtd-plugin-eds.h
index 6d8b8cab..6eea2c4a 100644
--- a/src/plugins/eds/gtd-plugin-eds.h
+++ b/src/plugins/eds/gtd-plugin-eds.h
@@ -18,7 +18,7 @@
 
 #pragma once
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 G_BEGIN_DECLS
 
diff --git a/src/plugins/eds/gtd-provider-eds.h b/src/plugins/eds/gtd-provider-eds.h
index 3cfea27f..5ffe4ffe 100644
--- a/src/plugins/eds/gtd-provider-eds.h
+++ b/src/plugins/eds/gtd-provider-eds.h
@@ -18,7 +18,7 @@
 
 #pragma once
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include "gtd-eds.h"
 
diff --git a/src/plugins/eds/gtd-provider-goa.h b/src/plugins/eds/gtd-provider-goa.h
index 6f9632a1..42625cd0 100644
--- a/src/plugins/eds/gtd-provider-goa.h
+++ b/src/plugins/eds/gtd-provider-goa.h
@@ -21,7 +21,7 @@
 
 #define GOA_API_IS_SUBJECT_TO_CHANGE 1
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 #include "gtd-provider-eds.h"
 
 #include <glib.h>
diff --git a/src/plugins/eds/gtd-provider-local.h b/src/plugins/eds/gtd-provider-local.h
index 8cb84021..90ff8a64 100644
--- a/src/plugins/eds/gtd-provider-local.h
+++ b/src/plugins/eds/gtd-provider-local.h
@@ -19,7 +19,7 @@
 #ifndef GTD_PROVIDER_LOCAL_H
 #define GTD_PROVIDER_LOCAL_H
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 #include "gtd-provider-eds.h"
 
 #include <glib.h>
diff --git a/src/plugins/eds/gtd-task-eds.c b/src/plugins/eds/gtd-task-eds.c
index 1911ad19..c5d5d1e2 100644
--- a/src/plugins/eds/gtd-task-eds.c
+++ b/src/plugins/eds/gtd-task-eds.c
@@ -21,7 +21,7 @@
 #include "gtd-eds-autoptr.h"
 #include "gtd-task-eds.h"
 
-#define ICAL_X_GNOME_TODO_POSITION "X-GNOME-TODO-POSITION"
+#define ICAL_X_ENDEAVOUR_POSITION "X-ENDEAVOUR-POSITION"
 
 struct _GtdTaskEds
 {
@@ -428,7 +428,7 @@ gtd_task_eds_get_position (GtdTask *task)
   self = GTD_TASK_EDS (task);
   ical_comp = e_cal_component_get_icalcomponent (self->new_component);
 
-  value = e_cal_util_component_dup_x_property (ical_comp, ICAL_X_GNOME_TODO_POSITION);
+  value = e_cal_util_component_dup_x_property (ical_comp, ICAL_X_ENDEAVOUR_POSITION);
   if (value)
     position = g_ascii_strtoll (value, NULL, 10);
 
@@ -448,7 +448,7 @@ gtd_task_eds_set_position (GtdTask *task,
     value = g_strdup_printf ("%" G_GINT64_FORMAT, position);
   ical_comp = e_cal_component_get_icalcomponent (self->new_component);
 
-  e_cal_util_component_set_x_property (ical_comp, ICAL_X_GNOME_TODO_POSITION, value);
+  e_cal_util_component_set_x_property (ical_comp, ICAL_X_ENDEAVOUR_POSITION, value);
 }
 
 static const gchar*
diff --git a/src/plugins/eds/gtd-task-eds.h b/src/plugins/eds/gtd-task-eds.h
index 7b5648df..078f5851 100644
--- a/src/plugins/eds/gtd-task-eds.h
+++ b/src/plugins/eds/gtd-task-eds.h
@@ -19,7 +19,7 @@
 #ifndef GTD_TASK_EDS_H
 #define GTD_TASK_EDS_H
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include "gtd-eds.h"
 
diff --git a/src/plugins/eds/gtd-task-list-eds.c b/src/plugins/eds/gtd-task-list-eds.c
index fcde62bd..19bcdab8 100644
--- a/src/plugins/eds/gtd-task-list-eds.c
+++ b/src/plugins/eds/gtd-task-list-eds.c
@@ -18,7 +18,7 @@
 
 #define G_LOG_DOMAIN "GtdTaskListEds"
 
-#include "e-source-gnome-todo.h"
+#include "e-source-endeavour.h"
 #include "gtd-debug.h"
 #include "gtd-eds-autoptr.h"
 #include "gtd-provider-eds.h"
@@ -175,7 +175,7 @@ static void
 maybe_migrate_todo_api_version (GtdTaskListEds *self)
 {
   g_autoptr (GHashTable) changed_tasks = NULL;
-  ESourceGnomeTodo *gnome_todo_extension;
+  ESourceEndeavour *endeavour_extension;
   gboolean api_version_changed;
   guint api_version;
   guint i;
@@ -186,14 +186,14 @@ maybe_migrate_todo_api_version (GtdTaskListEds *self)
    * Ensure the type so that it is available for introspection when
    * calling e_source_get_extension().
    */
-  g_type_ensure (E_TYPE_SOURCE_GNOME_TODO);
+  g_type_ensure (E_TYPE_SOURCE_ENDEAVOUR);
 
   api_version_changed = FALSE;
-  gnome_todo_extension = e_source_get_extension (self->source, E_SOURCE_EXTENSION_GNOME_TODO);
-  api_version = e_source_gnome_todo_get_api_version (gnome_todo_extension);
+  endeavour_extension = e_source_get_extension (self->source, E_SOURCE_EXTENSION_ENDEAVOUR);
+  api_version = e_source_endeavour_get_api_version (endeavour_extension);
   changed_tasks = g_hash_table_new (g_direct_hash, g_direct_equal);
 
-  g_debug ("%s: GNOME To Do API version %u",
+  g_debug ("%s: Endeavour API version %u",
            gtd_task_list_get_name (GTD_TASK_LIST (self)),
            api_version);
 
@@ -204,11 +204,11 @@ maybe_migrate_todo_api_version (GtdTaskListEds *self)
       if (api_version > migration_vtable[i].api_version)
         continue;
 
-      g_debug ("  Migrating task list to GNOME To Do API v%u", new_api_version);
+      g_debug ("  Migrating task list to Endeavour API v%u", new_api_version);
 
       migration_vtable[i].migrate (self, changed_tasks);
 
-      e_source_gnome_todo_set_api_version (gnome_todo_extension, new_api_version);
+      e_source_endeavour_set_api_version (endeavour_extension, new_api_version);
       api_version_changed = TRUE;
     }
 
diff --git a/src/plugins/eds/gtd-task-list-eds.h b/src/plugins/eds/gtd-task-list-eds.h
index d2fa5d1d..5a712957 100644
--- a/src/plugins/eds/gtd-task-list-eds.h
+++ b/src/plugins/eds/gtd-task-list-eds.h
@@ -19,7 +19,7 @@
 #ifndef GTD_TASK_LIST_EDS_H
 #define GTD_TASK_LIST_EDS_H
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include "gtd-eds.h"
 
diff --git a/src/plugins/eds/meson.build b/src/plugins/eds/meson.build
index 18d5b536..50705a30 100644
--- a/src/plugins/eds/meson.build
+++ b/src/plugins/eds/meson.build
@@ -10,7 +10,7 @@ plugins_deps += [
 ]
 
 plugins_sources += files(
-  'e-source-gnome-todo.c',
+  'e-source-endeavour.c',
   'gtd-plugin-eds.c',
   'gtd-provider-eds.c',
   'gtd-provider-goa.c',
diff --git a/src/plugins/inbox-panel/gtd-inbox-panel.c b/src/plugins/inbox-panel/gtd-inbox-panel.c
index 8b4fd9a6..b3bdb39b 100644
--- a/src/plugins/inbox-panel/gtd-inbox-panel.c
+++ b/src/plugins/inbox-panel/gtd-inbox-panel.c
@@ -23,7 +23,7 @@
 
 #include "gtd-inbox-panel.h"
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include <glib/gi18n.h>
 #include <math.h>
diff --git a/src/plugins/inbox-panel/inbox-panel-plugin.c b/src/plugins/inbox-panel/inbox-panel-plugin.c
index abfb208e..b5a180c4 100644
--- a/src/plugins/inbox-panel/inbox-panel-plugin.c
+++ b/src/plugins/inbox-panel/inbox-panel-plugin.c
@@ -20,7 +20,7 @@
 
 #define G_LOG_DOMAIN "GtdPluginInboxPanel"
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 #include "gtd-inbox-panel.h"
 
 G_MODULE_EXPORT void
diff --git a/src/plugins/inbox-panel/inbox-panel.plugin b/src/plugins/inbox-panel/inbox-panel.plugin
index f2d35b75..1ee01140 100644
--- a/src/plugins/inbox-panel/inbox-panel.plugin
+++ b/src/plugins/inbox-panel/inbox-panel.plugin
@@ -4,7 +4,7 @@ Module = inbox-panel
 Description = A panel to show tasks in the inbox
 Version = @VERSION@
 Authors = Georges Basile Stavracas Neto <gbsneto gnome org>
-Copyright = Copyleft © The To Do maintainers
+Copyright = Copyleft © The Endeavour maintainers
 Website = https://wiki.gnome.org/Apps/Todo
 Hidden = true
 Builtin = true
diff --git a/src/plugins/meson.build b/src/plugins/meson.build
index 15055bca..5628bd1b 100644
--- a/src/plugins/meson.build
+++ b/src/plugins/meson.build
@@ -4,13 +4,13 @@ plugins_incs = [
 ]
 
 plugins_sources = []
-plugins_deps = [ gnome_todo_deps ]
+plugins_deps = [ endeavour_deps ]
 plugins_ldflags = []
 plugins_libs = []
 plugins_confs = []
 
 plugins_conf = configuration_data()
-plugins_conf.set('VERSION', gnome_todo_version)
+plugins_conf.set('VERSION', endeavour_version)
 
 subdir('all-tasks-panel')
 subdir('background')
diff --git a/src/plugins/next-week-panel/gtd-next-week-panel.c 
b/src/plugins/next-week-panel/gtd-next-week-panel.c
index 41e5050e..686159d4 100644
--- a/src/plugins/next-week-panel/gtd-next-week-panel.c
+++ b/src/plugins/next-week-panel/gtd-next-week-panel.c
@@ -23,7 +23,7 @@
 
 #include "gtd-next-week-panel.h"
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include <glib/gi18n.h>
 #include <math.h>
diff --git a/src/plugins/next-week-panel/next-week-panel-plugin.c 
b/src/plugins/next-week-panel/next-week-panel-plugin.c
index 332a2151..29af4198 100644
--- a/src/plugins/next-week-panel/next-week-panel-plugin.c
+++ b/src/plugins/next-week-panel/next-week-panel-plugin.c
@@ -22,7 +22,7 @@
 
 #include "gtd-next-week-panel.h"
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 G_MODULE_EXPORT void
 next_week_panel_plugin_register_types (PeasObjectModule *module)
diff --git a/src/plugins/next-week-panel/next-week-panel.plugin 
b/src/plugins/next-week-panel/next-week-panel.plugin
index 48109354..0f029add 100644
--- a/src/plugins/next-week-panel/next-week-panel.plugin
+++ b/src/plugins/next-week-panel/next-week-panel.plugin
@@ -4,7 +4,7 @@ Module = next-week-panel
 Description = A panel to show tasks scheduled for the next 7 days
 Version = @VERSION@
 Authors = Georges Basile Stavracas Neto <gbsneto gnome org>
-Copyright = Copyleft © The To Do maintainers
+Copyright = Copyleft © The Endeavour maintainers
 Website = https://wiki.gnome.org/Apps/Todo
 Builtin = true
 License = GPL
diff --git a/src/plugins/peace/gtd-peace-omni-area-addin.h b/src/plugins/peace/gtd-peace-omni-area-addin.h
index 9006b30c..8b836536 100644
--- a/src/plugins/peace/gtd-peace-omni-area-addin.h
+++ b/src/plugins/peace/gtd-peace-omni-area-addin.h
@@ -20,7 +20,7 @@
 
 #pragma once
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 G_BEGIN_DECLS
 
diff --git a/src/plugins/peace/peace.plugin b/src/plugins/peace/peace.plugin
index 0b3b2487..d7e85ea2 100644
--- a/src/plugins/peace/peace.plugin
+++ b/src/plugins/peace/peace.plugin
@@ -3,7 +3,7 @@ Name = Peace
 Module = peace
 Description = Smile, breathe and go slowly
 Authors = Georges Basile Stavracas Neto <georges stavracas gmail com>
-Copyright = Copyleft © The To Do maintainers
+Copyright = Copyleft © The Endeavour maintainers
 Website = https://wiki.gnome.org/Apps/Todo
 Builtin = true
 License = GPL
diff --git a/src/plugins/scheduled-panel/gtd-panel-scheduled.c 
b/src/plugins/scheduled-panel/gtd-panel-scheduled.c
index c105ae46..8d557b86 100644
--- a/src/plugins/scheduled-panel/gtd-panel-scheduled.c
+++ b/src/plugins/scheduled-panel/gtd-panel-scheduled.c
@@ -18,7 +18,7 @@
 
 #define G_LOG_DOMAIN "GtdPanelScheduled"
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include "gtd-panel-scheduled.h"
 
diff --git a/src/plugins/scheduled-panel/gtd-plugin-scheduled-panel.h 
b/src/plugins/scheduled-panel/gtd-plugin-scheduled-panel.h
index 74281af2..e5391f3c 100644
--- a/src/plugins/scheduled-panel/gtd-plugin-scheduled-panel.h
+++ b/src/plugins/scheduled-panel/gtd-plugin-scheduled-panel.h
@@ -19,7 +19,7 @@
 #ifndef GTD_PLUGIN_SCHEDULED_PANEL_H
 #define GTD_PLUGIN_SCHEDULED_PANEL_H
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include <glib.h>
 
diff --git a/src/plugins/scheduled-panel/scheduled-panel.plugin 
b/src/plugins/scheduled-panel/scheduled-panel.plugin
index 79bcf79b..2cb78d88 100644
--- a/src/plugins/scheduled-panel/scheduled-panel.plugin
+++ b/src/plugins/scheduled-panel/scheduled-panel.plugin
@@ -4,7 +4,7 @@ Module = scheduled-panel
 Description = A panel to show scheduled tasks
 Version = @VERSION@
 Authors = Georges Basile Stavracas Neto <gbsneto gnome org>
-Copyright = Copyleft © The To Do maintainers
+Copyright = Copyleft © The Endeavour maintainers
 Website = https://wiki.gnome.org/Apps/Todo
 Builtin = true
 License = GPL
diff --git a/src/plugins/task-lists-workspace/gtd-sidebar.h b/src/plugins/task-lists-workspace/gtd-sidebar.h
index 20d603bb..d85a9961 100644
--- a/src/plugins/task-lists-workspace/gtd-sidebar.h
+++ b/src/plugins/task-lists-workspace/gtd-sidebar.h
@@ -20,7 +20,7 @@
 
 #pragma once
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 G_BEGIN_DECLS
 
diff --git a/src/plugins/task-lists-workspace/gtd-task-lists-workspace.h 
b/src/plugins/task-lists-workspace/gtd-task-lists-workspace.h
index 2cd699af..0cbc97ae 100644
--- a/src/plugins/task-lists-workspace/gtd-task-lists-workspace.h
+++ b/src/plugins/task-lists-workspace/gtd-task-lists-workspace.h
@@ -22,7 +22,7 @@
 
 #include <gtk/gtk.h>
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 G_BEGIN_DECLS
 
diff --git a/src/plugins/task-lists-workspace/task-lists-workspace-plugin.c 
b/src/plugins/task-lists-workspace/task-lists-workspace-plugin.c
index 1f9de4ab..78d071d1 100644
--- a/src/plugins/task-lists-workspace/task-lists-workspace-plugin.c
+++ b/src/plugins/task-lists-workspace/task-lists-workspace-plugin.c
@@ -18,7 +18,7 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include "gtd-task-lists-workspace.h"
 
diff --git a/src/plugins/task-lists-workspace/task-lists-workspace.plugin 
b/src/plugins/task-lists-workspace/task-lists-workspace.plugin
index dd03cbd6..2b2f090b 100644
--- a/src/plugins/task-lists-workspace/task-lists-workspace.plugin
+++ b/src/plugins/task-lists-workspace/task-lists-workspace.plugin
@@ -4,7 +4,7 @@ Module = task-lists-workspace
 Description = Plugin implementing the task lists workspace
 Version = @VERSION@
 Authors = Georges Basile Stavracas Neto <gbsneto gnome org>
-Copyright = Copyleft © The To Do maintainers
+Copyright = Copyleft © The Endeavour maintainers
 Website = https://wiki.gnome.org/Apps/Todo
 Builtin = true
 Hidden = true
diff --git a/src/plugins/today-panel/gtd-panel-today.c b/src/plugins/today-panel/gtd-panel-today.c
index 4c547c7f..963d877d 100644
--- a/src/plugins/today-panel/gtd-panel-today.c
+++ b/src/plugins/today-panel/gtd-panel-today.c
@@ -18,7 +18,7 @@
 
 #define G_LOG_DOMAIN "GtdPanelToday"
 
-#include <gnome-todo.h>
+#include <endeavour.h>
 #include "gtd-panel-today.h"
 
 #include <glib/gi18n.h>
diff --git a/src/plugins/today-panel/gtd-today-omni-area-addin.c 
b/src/plugins/today-panel/gtd-today-omni-area-addin.c
index cd3def37..d92979de 100644
--- a/src/plugins/today-panel/gtd-today-omni-area-addin.c
+++ b/src/plugins/today-panel/gtd-today-omni-area-addin.c
@@ -20,7 +20,7 @@
 
 #include "gtd-today-omni-area-addin.h"
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 #include "config.h"
 
 #include <glib/gi18n.h>
diff --git a/src/plugins/today-panel/today-panel-plugin.c b/src/plugins/today-panel/today-panel-plugin.c
index 89a60e79..9dbc6ce5 100644
--- a/src/plugins/today-panel/today-panel-plugin.c
+++ b/src/plugins/today-panel/today-panel-plugin.c
@@ -16,7 +16,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <gnome-todo.h>
+#include <endeavour.h>
 
 #include "gtd-panel-today.h"
 #include "gtd-today-omni-area-addin.h"
diff --git a/src/plugins/today-panel/today-panel.plugin b/src/plugins/today-panel/today-panel.plugin
index b27df31e..89640ff5 100644
--- a/src/plugins/today-panel/today-panel.plugin
+++ b/src/plugins/today-panel/today-panel.plugin
@@ -4,7 +4,7 @@ Module = today-panel
 Description = A panel to show tasks scheduled for today
 Version = @VERSION@
 Authors = Georges Basile Stavracas Neto <gbsneto gnome org>
-Copyright = Copyleft © The To Do maintainers
+Copyright = Copyleft © The Endeavour maintainers
 Website = https://wiki.gnome.org/Apps/Todo
 Builtin = true
 Hidden = true
diff --git a/src/plugins/todo-txt/gtd-plugin-todo-txt.c b/src/plugins/todo-txt/gtd-plugin-todo-txt.c
index 95c66a7d..86334d6c 100644
--- a/src/plugins/todo-txt/gtd-plugin-todo-txt.c
+++ b/src/plugins/todo-txt/gtd-plugin-todo-txt.c
@@ -27,7 +27,7 @@
 
 /**
  * The #GtdPluginTodoTxt is a class that loads Todo.txt
- * provider of GNOME To Do.
+ * provider of Endeavour.
  */
 
 struct _GtdPluginTodoTxt
diff --git a/src/plugins/todo-txt/gtd-plugin-todo-txt.h b/src/plugins/todo-txt/gtd-plugin-todo-txt.h
index cc3eb12e..2120ce84 100644
--- a/src/plugins/todo-txt/gtd-plugin-todo-txt.h
+++ b/src/plugins/todo-txt/gtd-plugin-todo-txt.h
@@ -19,7 +19,7 @@
 #ifndef GTD_TODO_TXT_PLUGIN_H
 #define GTD_TODO_TXT_PLUGIN_H
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include <glib.h>
 
diff --git a/src/plugins/todo-txt/gtd-provider-todo-txt.c b/src/plugins/todo-txt/gtd-provider-todo-txt.c
index 532b53de..d06ab15a 100644
--- a/src/plugins/todo-txt/gtd-provider-todo-txt.c
+++ b/src/plugins/todo-txt/gtd-provider-todo-txt.c
@@ -294,7 +294,7 @@ parse_task (GtdProviderTodoTxt  *self,
 
   /*
    * Create the list if it doesn't exist yet; this might happen with todo.txt files
-   * that are not saved from GNOME To Do.
+   * that are not saved from Endeavour.
    */
   if (!g_hash_table_contains (self->lists, list_name))
     {
diff --git a/src/plugins/todo-txt/gtd-provider-todo-txt.h b/src/plugins/todo-txt/gtd-provider-todo-txt.h
index a7e8f742..87bd3c77 100644
--- a/src/plugins/todo-txt/gtd-provider-todo-txt.h
+++ b/src/plugins/todo-txt/gtd-provider-todo-txt.h
@@ -19,7 +19,7 @@
 #ifndef GTD_PROVIDER_TODO_TXT_H
 #define GTD_PROVIDER_TODO_TXT_H
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 #include "gtd-task-todo-txt.h"
 
 #include <glib.h>
diff --git a/src/plugins/todo-txt/gtd-task-todo-txt.h b/src/plugins/todo-txt/gtd-task-todo-txt.h
index 11ffdb2c..26879fc4 100644
--- a/src/plugins/todo-txt/gtd-task-todo-txt.h
+++ b/src/plugins/todo-txt/gtd-task-todo-txt.h
@@ -18,7 +18,7 @@
 
 #pragma once
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 G_BEGIN_DECLS
 
diff --git a/src/plugins/todo-txt/gtd-todo-txt-parser.h b/src/plugins/todo-txt/gtd-todo-txt-parser.h
index b49721c4..31646871 100644
--- a/src/plugins/todo-txt/gtd-todo-txt-parser.h
+++ b/src/plugins/todo-txt/gtd-todo-txt-parser.h
@@ -21,7 +21,7 @@
 
 #define INDENT_LEN 4
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 #include "gtd-task-todo-txt.h"
 
 #include <glib.h>
diff --git a/src/plugins/todo-txt/meson.build b/src/plugins/todo-txt/meson.build
index 9128b073..4c878a17 100644
--- a/src/plugins/todo-txt/meson.build
+++ b/src/plugins/todo-txt/meson.build
@@ -13,12 +13,12 @@ plugins_libs += static_library(
   'todotxt',
               sources: sources,
   include_directories: plugins_incs,
-         dependencies: gnome_todo_deps
+         dependencies: endeavour_deps
 )
 
 install_data(
   'org.gnome.todo.txt.gschema.xml',
-  install_dir: gnome_todo_schemadir
+  install_dir: endeavour_schemadir
 )
 
 plugin_data = plugin_name + '.plugin'
diff --git a/src/plugins/todo-txt/org.gnome.todo.txt.gschema.xml 
b/src/plugins/todo-txt/org.gnome.todo.txt.gschema.xml
index 70d9f788..db2b37b0 100644
--- a/src/plugins/todo-txt/org.gnome.todo.txt.gschema.xml
+++ b/src/plugins/todo-txt/org.gnome.todo.txt.gschema.xml
@@ -1,5 +1,5 @@
 <?xml version="1.0" encoding="UTF-8"?>
-<schemalist gettext-domain="gnome-todo">
+<schemalist gettext-domain="endeavour">
     <schema id="org.gnome.todo.plugins.todo-txt" path="/org/gnome/todo/plugins/todo-txt/">
         <key name="file" type="s">
             <default>''</default>
diff --git a/src/plugins/todo-txt/syntax.md b/src/plugins/todo-txt/syntax.md
index 15599297..4e406519 100644
--- a/src/plugins/todo-txt/syntax.md
+++ b/src/plugins/todo-txt/syntax.md
@@ -1,15 +1,15 @@
 # Syntax For Todo.txt
 
 This document describes the syntax that users should follow when manually 
-editing a Todo.txt managed by GNOME To Do. The rules are based on general
+editing a Todo.txt managed by Endeavour. The rules are based on general
 todo.txt rules. Any deviation from the same is clearly mentioned.
-The deviation from common todo.txt rules is due to GNOME To Do specific
+The deviation from common todo.txt rules is due to Endeavour specific
 features and behaviour.
 
 ## Line Type
 
 Currently we have general lines with task desctiption and custom
-lines with GNOME To Do specific descriptions. The custom lines
+lines with Endeavour specific descriptions. The custom lines
 start with h:1 and are intended not to be edited by the users.
 
   1) The task line describing a task
@@ -28,7 +28,7 @@ indent x (Priority) Creation-Date Completion-Date title due:date note:"descripti
        :Priority                 - (Optional) Should appear in closed parenthesis, can be 
                                                     A(high), B(medium), C(low) and any other character is 
taken as 
                                                     default no priority
-                                                    (GNOME To Do Supports 3 priority level High, Medium and 
low)
+                                                    (Endeavour Supports 3 priority level High, Medium and 
low)
        :Creation-Date        - (Optional) Date on which the task was created
        :Completion-Date      - (Optional) Should be mentioned if Creation Date is mentioned
        :title                - (Required) Title describing the task
@@ -36,11 +36,11 @@ indent x (Priority) Creation-Date Completion-Date title due:date note:"descripti
        :note:"description"   - (Optional) Long Description for the task
        :@List                - (Required) The Context of the task. Although todo.txt doesn't
                                                    requires a context to be mentioned but since every task in
-                                                   GNOME To Do belongs to a list and hence it is necessary.
+                                                   Endeavour belongs to a list and hence it is necessary.
 
 ## Custom Lines
 
-Custom Lines appears the end of todo.txt and starts with h:1. At the present To Do specifies
+Custom Lines appears the end of todo.txt and starts with h:1. At the present Endeavour specifies
 two custom lines for storing tasklists and their color.
 
 ### List Line
@@ -54,7 +54,7 @@ and Shopping
 
 ### Color Line
 
-The Color line describes background color for GNOME To Do list. It starts with a
+The Color line describes background color for Endeavour list. It starts with a
 prefix h:1 Colors and color desciption appears as listname:hexcode and are separated
 by space.
 
diff --git a/src/plugins/todo-txt/todo-txt.plugin.in b/src/plugins/todo-txt/todo-txt.plugin.in
index 48788137..c2023af8 100644
--- a/src/plugins/todo-txt/todo-txt.plugin.in
+++ b/src/plugins/todo-txt/todo-txt.plugin.in
@@ -1,10 +1,10 @@
 [Plugin]
 Name = Todo.Txt
 Module = todo-txt
-Description = Todo.txt plugin for GNOME To Do (Experimental)
+Description = Todo.txt plugin for Endeavour (Experimental)
 Version = @VERSION@
 Authors = Rohit Kaushik <kaushikrohit325 gmail com>
-Copyright = Copyleft © The To Do maintainers
+Copyright = Copyleft © The Endeavour maintainers
 Website = https://wiki.gnome.org/Apps/Todo
 Builtin = true
 License = GPL
diff --git a/src/plugins/todoist/gtd-plugin-todoist.h b/src/plugins/todoist/gtd-plugin-todoist.h
index 37060635..19b7bc4e 100644
--- a/src/plugins/todoist/gtd-plugin-todoist.h
+++ b/src/plugins/todoist/gtd-plugin-todoist.h
@@ -19,7 +19,7 @@
 #ifndef GTD_TODOIST_PLUGIN_H
 #define GTD_TODOIST_PLUGIN_H
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include <glib.h>
 
diff --git a/src/plugins/todoist/gtd-provider-todoist.c b/src/plugins/todoist/gtd-provider-todoist.c
index b92489e7..20970995 100644
--- a/src/plugins/todoist/gtd-provider-todoist.c
+++ b/src/plugins/todoist/gtd-provider-todoist.c
@@ -552,7 +552,7 @@ check_post_response_for_errors (RestProxyCall     *call,
               g_set_error (error,
                            GTD_PROVIDER_TODOIST_ERROR,
                            GTD_PROVIDER_TODOIST_ERROR_NOT_ALLOWED,
-                           _("GNOME To Do doesn’t have the necessary permissions to perform this action: 
%s"),
+                           _("Endeavour doesn’t have the necessary permissions to perform this action: %s"),
                            message);
               break;
 
@@ -560,7 +560,7 @@ check_post_response_for_errors (RestProxyCall     *call,
               g_set_error (error,
                            GTD_PROVIDER_TODOIST_ERROR,
                            GTD_PROVIDER_TODOIST_ERROR_INVALID_RESPONSE,
-                           _("Invalid response received from Todoist servers. Please reload GNOME To Do."));
+                           _("Invalid response received from Todoist servers. Please reload Endeavour."));
             }
         }
     }
diff --git a/src/plugins/todoist/gtd-provider-todoist.h b/src/plugins/todoist/gtd-provider-todoist.h
index 8cb3a768..7885495a 100644
--- a/src/plugins/todoist/gtd-provider-todoist.h
+++ b/src/plugins/todoist/gtd-provider-todoist.h
@@ -21,7 +21,7 @@
 
 #define GOA_API_IS_SUBJECT_TO_CHANGE
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include <glib.h>
 #include <goa/goa.h>
diff --git a/src/plugins/todoist/gtd-todoist-preferences-panel.h 
b/src/plugins/todoist/gtd-todoist-preferences-panel.h
index 95f3636a..308d0c40 100644
--- a/src/plugins/todoist/gtd-todoist-preferences-panel.h
+++ b/src/plugins/todoist/gtd-todoist-preferences-panel.h
@@ -21,7 +21,7 @@
 #ifndef GTD_TODOIST_PREFERENCES_PANEL_H
 #define GTD_TODOIST_PREFERENCES_PANEL_H
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include <glib.h>
 #include <goa/goa.h>
diff --git a/src/plugins/todoist/meson.build b/src/plugins/todoist/meson.build
index a8ec97f1..593995fd 100644
--- a/src/plugins/todoist/meson.build
+++ b/src/plugins/todoist/meson.build
@@ -8,7 +8,7 @@ sources = files(
   'gtd-' + plugin_name + '-preferences-panel.c'
 )
 
-todoist_deps = gnome_todo_deps + [
+todoist_deps = endeavour_deps + [
   dependency('rest-0.7'),
   dependency('json-glib-1.0')
 ]
diff --git a/src/plugins/todoist/todoist.plugin.in b/src/plugins/todoist/todoist.plugin.in
index 83fa0e34..a15137d1 100644
--- a/src/plugins/todoist/todoist.plugin.in
+++ b/src/plugins/todoist/todoist.plugin.in
@@ -1,10 +1,10 @@
 [Plugin]
 Name = Todoist
 Module = todoist
-Description = Todoist integration for GNOME To Do (Experimental)
+Description = Todoist integration for Endeavour (Experimental)
 Version = @VERSION@
 Authors = Rohit Kaushik <kaushikrohit325 gmail com>
-Copyright = Copyleft © The To Do maintainers
+Copyright = Copyleft © The Endeavour maintainers
 Website = https://wiki.gnome.org/Apps/Todo
 Builtin = true
 License = GPL
diff --git a/src/plugins/unscheduled-panel/meson.build b/src/plugins/unscheduled-panel/meson.build
index f2c648a0..a8a4fa16 100644
--- a/src/plugins/unscheduled-panel/meson.build
+++ b/src/plugins/unscheduled-panel/meson.build
@@ -1,6 +1,6 @@
 plugin_name = 'unscheduled-panel'
 
-plugin_dir = join_paths(gnome_todo_pluginsdir, plugin_name)
+plugin_dir = join_paths(endeavour_pluginsdir, plugin_name)
 
 install_data(
   join_paths(plugin_name, '__init__.py'),
diff --git a/src/plugins/unscheduled-panel/unscheduled-panel.plugin 
b/src/plugins/unscheduled-panel/unscheduled-panel.plugin
index a72c7c64..8a06d246 100644
--- a/src/plugins/unscheduled-panel/unscheduled-panel.plugin
+++ b/src/plugins/unscheduled-panel/unscheduled-panel.plugin
@@ -4,7 +4,7 @@ Module = unscheduled-panel
 Description = Adds a panel to show unscheduled tasks
 Version = @VERSION@
 Authors = Georges Basile Stavracas Neto <gbsneto gnome org>
-Copyright = Copyleft © The To Do maintainers
+Copyright = Copyleft © The Endeavour maintainers
 Website = https://wiki.gnome.org/Apps/Todo
 Builtin = false
 Hidden = false
diff --git a/src/plugins/unscheduled-panel/unscheduled-panel/__init__.py 
b/src/plugins/unscheduled-panel/unscheduled-panel/__init__.py
index ae5bb3a7..407a76d2 100644
--- a/src/plugins/unscheduled-panel/unscheduled-panel/__init__.py
+++ b/src/plugins/unscheduled-panel/unscheduled-panel/__init__.py
@@ -26,8 +26,8 @@ from gi.repository import Gio, GLib, GObject, Gtd, Gtk, Peas
 
 try:
     import gettext
-    gettext.bindtextdomain('gnome-todo')
-    gettext.textdomain('gnome-todo')
+    gettext.bindtextdomain('endeavour')
+    gettext.textdomain('endeavour')
     _ = gettext.gettext
 except Exception:
     def _(s):
diff --git a/src/plugins/welcome/gtd-welcome-workspace.h b/src/plugins/welcome/gtd-welcome-workspace.h
index 825890bf..a5b10074 100644
--- a/src/plugins/welcome/gtd-welcome-workspace.h
+++ b/src/plugins/welcome/gtd-welcome-workspace.h
@@ -20,7 +20,7 @@
 
 #pragma once
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 G_BEGIN_DECLS
 
diff --git a/src/plugins/welcome/welcome.plugin b/src/plugins/welcome/welcome.plugin
index afc685e1..db36e47f 100644
--- a/src/plugins/welcome/welcome.plugin
+++ b/src/plugins/welcome/welcome.plugin
@@ -1,9 +1,9 @@
 [Plugin]
 Name = Welcome
 Module = welcome
-Description = Welcome workspace for GNOME To Do
+Description = Welcome workspace for Endeavour
 Authors = Georges Basile Stavracas Neto <georges stavracas gmail com>
-Copyright = Copyleft © The To Do maintainers
+Copyright = Copyleft © The Endeavour maintainers
 Website = https://wiki.gnome.org/Apps/Todo
 Builtin = true
 License = GPL
diff --git a/tests/dummy-provider.c b/tests/dummy-provider.c
index 729b38e6..6d6041f6 100644
--- a/tests/dummy-provider.c
+++ b/tests/dummy-provider.c
@@ -20,7 +20,7 @@
 
 #define G_LOG_DOMAIN "DummyProvider"
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include "gtd-debug.h"
 #include "dummy-provider.h"
diff --git a/tests/dummy-provider.h b/tests/dummy-provider.h
index 6520c068..51ba8fbe 100644
--- a/tests/dummy-provider.h
+++ b/tests/dummy-provider.h
@@ -20,7 +20,7 @@
 
 #pragma once
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 G_BEGIN_DECLS
 
diff --git a/tests/interactive/test-animation.c b/tests/interactive/test-animation.c
index 011497d9..6541551c 100644
--- a/tests/interactive/test-animation.c
+++ b/tests/interactive/test-animation.c
@@ -268,7 +268,7 @@ main (gint   argc,
   GtkWindow *window;
 
   g_set_prgname ("test-colorbutton");
-  g_set_application_name ("GNOME To Do | Widget Test");
+  g_set_application_name ("Endeavour | Widget Test");
 
   gtk_init ();
 
diff --git a/tests/interactive/test-colorbutton.c b/tests/interactive/test-colorbutton.c
index 1387f10c..065c9782 100644
--- a/tests/interactive/test-colorbutton.c
+++ b/tests/interactive/test-colorbutton.c
@@ -43,7 +43,7 @@ main (gint   argc,
   guint i;
 
   g_set_prgname ("test-colorbutton");
-  g_set_application_name ("GNOME To Do | Color Button Test");
+  g_set_application_name ("Endeavour | Color Button Test");
 
   gtk_init ();
 
diff --git a/tests/interactive/test-filter-sort.c b/tests/interactive/test-filter-sort.c
index 3894f509..a356e3cf 100644
--- a/tests/interactive/test-filter-sort.c
+++ b/tests/interactive/test-filter-sort.c
@@ -216,7 +216,7 @@ main (gint   argc,
   GtkWidget *vbox = NULL;
 
   g_set_prgname ("test-filter-sort");
-  g_set_application_name ("GNOME To Do | Filter & Sort Test");
+  g_set_application_name ("Endeavour | Filter & Sort Test");
 
   gtk_init ();
   gtd_log_init ();
diff --git a/tests/interactive/test-star-widget.c b/tests/interactive/test-star-widget.c
index 0f8452b5..cfb102c4 100644
--- a/tests/interactive/test-star-widget.c
+++ b/tests/interactive/test-star-widget.c
@@ -32,7 +32,7 @@ main (gint   argc,
   GtkWindow *window = NULL;
 
   g_set_prgname ("test-star-widget");
-  g_set_application_name ("GNOME To Do | Star Widget");
+  g_set_application_name ("Endeavour | Star Widget");
 
   gtk_init ();
   gtd_log_init ();
diff --git a/tests/interactive/test-task-model.c b/tests/interactive/test-task-model.c
index aef02db8..aa61ba91 100644
--- a/tests/interactive/test-task-model.c
+++ b/tests/interactive/test-task-model.c
@@ -119,7 +119,7 @@ main (gint   argc,
   GtkWidget *listbox = NULL;
 
   g_set_prgname ("test-task-model");
-  g_set_application_name ("GNOME To Do | Task Model Test");
+  g_set_application_name ("Endeavour | Task Model Test");
 
   gtk_init ();
   gtd_log_init ();
diff --git a/tests/interactive/test-widget.c b/tests/interactive/test-widget.c
index 3df55845..32c1d2d8 100644
--- a/tests/interactive/test-widget.c
+++ b/tests/interactive/test-widget.c
@@ -110,7 +110,7 @@ main (gint   argc,
   GtkWindow *window;
 
   g_set_prgname ("test-colorbutton");
-  g_set_application_name ("GNOME To Do | Widget Test");
+  g_set_application_name ("Endeavour | Widget Test");
 
   gtk_init ();
 
diff --git a/tests/meson.build b/tests/meson.build
index a6d1d72c..c0e24302 100644
--- a/tests/meson.build
+++ b/tests/meson.build
@@ -16,7 +16,7 @@ libgtd_tests = static_library(
            'gtd_tests',
               sources : sources,
   include_directories : tests_incs,
-         dependencies : gnome_todo_deps,
+         dependencies : endeavour_deps,
                c_args : cflags,
 )
 
@@ -59,7 +59,7 @@ foreach static_test : static_tests
               static_test,
                    source,
                   c_args : static_test_cflags,
-            dependencies : gnome_todo_deps,
+            dependencies : endeavour_deps,
                      pie : true,
                link_with : tests_libs,
      include_directories : tests_incs,
@@ -93,7 +93,7 @@ foreach interactive_test : interactive_tests
   interactive_test_name,
                  source,
    include_directories: tests_incs,
-          dependencies: gnome_todo_deps,
+          dependencies: endeavour_deps,
                 c_args: cflags,
              link_with: tests_libs,
   )
diff --git a/tests/test-task-list.c b/tests/test-task-list.c
index 325ee3a6..cee6adb3 100644
--- a/tests/test-task-list.c
+++ b/tests/test-task-list.c
@@ -18,7 +18,7 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include "core/gtd-log.h"
 #include "gtd-task-list.h"
diff --git a/tests/test-task-model.c b/tests/test-task-model.c
index 11ef88c0..04da5a6d 100644
--- a/tests/test-task-model.c
+++ b/tests/test-task-model.c
@@ -18,7 +18,7 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#include "gnome-todo.h"
+#include "endeavour.h"
 
 #include "core/gtd-log.h"
 #include "models/gtd-task-model.h"


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/gui/gtd-window.c b/src/gui/gtd-window.c
index 99e2771c..1545f8cf 100644
--- a/src/gui/gtd-window.c
+++ b/src/gui/gtd-window.c
@@ -48,7 +48,7 @@
  * @stability:Unstable
  * @see_also:#GtdNotification
  *
  * The #GtdWindow is the main application window of GNOME To Do. Objects should
  * use this class to send notifications (see gtd_window_notify()), cancel notifications
  * (see gtd_window_cancel_notification()), change between selection and normal mode
  * and fine-tune the headerbar.
@@ -96,7 +96,7 @@ setup_development_build (GtdWindow *self)
 {
   GtkStyleContext *context;
 
-  g_message (_("This is a development build of To Do. You may experience errors, wrong behaviors, "
+  g_message (_("This is a development build of Endeavour. You may experience errors, wrong behaviors, "
                "and data loss."));
 
   context = gtk_widget_get_style_context (GTK_WIDGET (self));
@@ -48,7 +48,7 @@
  * @see_also:#GtdNotification
  *
- * The #GtdWindow is the main application window of GNOME To Do. Objects should
+ * The #GtdWindow is the main application window of Endeavour. Objects should
  * use this class to send notifications (see gtd_window_notify()), cancel notifications
  * (see gtd_window_cancel_notification()), change between selection and normal mode
diff --git a/src/main.c b/src/main.c
index 6f47752a..c25123ec 100644
--- a/src/main.c
+++ b/src/main.c
@@ -2,12 +2,12 @@
  * main.c
  * Copyright (C) 2015-2020 Georges Basile Stavracas Neto <georges stavracas gmail com>
  *
  * gnome-todo is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * gnome-todo is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  * See the GNU General Public License for more details.
@@ -34,7 +34,7 @@ main (gint    argc,
   bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
   textdomain (GETTEXT_PACKAGE);
 
-  g_set_application_name (_("To Do"));
+  g_set_application_name (_("Endeavour"));
 
   app = gtd_application_new ();
   g_application_set_default (G_APPLICATION (app));
@@ -2,12 +2,12 @@
  * Copyright (C) 2015-2020 Georges Basile Stavracas Neto <georges stavracas gmail com>
  *
- * gnome-todo is free software: you can redistribute it and/or modify it
+ * endeavour is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
  * Free Software Foundation, either version 3 of the License, or
@@ -2,12 +2,12 @@
  * (at your option) any later version.
  *
- * gnome-todo is distributed in the hope that it will be useful, but
+ * endeavour is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
diff --git a/src/plugins/background/gtd-plugin-background.c b/src/plugins/background/gtd-plugin-background.c
index f64d07aa..474e3761 100644
--- a/src/plugins/background/gtd-plugin-background.c
+++ b/src/plugins/background/gtd-plugin-background.c
@@ -86,7 +86,7 @@ get_window (void)
 }
 
 static gboolean
-is_gnome_todo_active (void)
+is_endeavour_active (void)
 {
   GListModel *toplevels;
   guint i;
@@ -137,7 +137,7 @@ update_background_portal (GtdPluginBackground *self)
   if (self->autostart)
     {
       commandline = g_ptr_array_new_with_free_func (g_free);
-      g_ptr_array_add (commandline, g_strdup ("gnome-todo"));
+      g_ptr_array_add (commandline, g_strdup ("endeavour"));
       g_ptr_array_add (commandline, g_strdup ("--gapplication-service"));
 
       background_flags |= XDP_BACKGROUND_FLAG_AUTOSTART;
@@ -178,7 +178,7 @@ start_update (GtdPluginBackground *self)
   GTD_ENTRY;
 
   window = get_window ();
-  if (gtk_widget_get_visible (GTK_WIDGET (window)) && is_gnome_todo_active ())
+  if (gtk_widget_get_visible (GTK_WIDGET (window)) && is_endeavour_active ())
     {
       update_background_portal (self);
     }
@@ -321,7 +321,7 @@ send_notification (GtdPluginBackground *self)
   window = GTD_WINDOW (get_window ());
 
   /*
    * If the user already focused To Do's window, we don't have to
    * notify about the number of tasks.
    */
   if (gtk_window_is_active (GTK_WINDOW (window)))
@@ -321,7 +321,7 @@ send_notification (GtdPluginBackground *self)
 
   /*
-   * If the user already focused To Do's window, we don't have to
+   * If the user already focused Endeavour's window, we don't have to
    * notify about the number of tasks.
    */
diff --git a/src/plugins/todoist/gtd-plugin-todoist.c b/src/plugins/todoist/gtd-plugin-todoist.c
index bc139f22..dcc3a58a 100644
--- a/src/plugins/todoist/gtd-plugin-todoist.c
+++ b/src/plugins/todoist/gtd-plugin-todoist.c
@@ -29,7 +29,7 @@
 
 /**
  * The #GtdPluginTodoist is a class that loads Todoist
  * provider of GNOME To Do.
  */
 
 struct _GtdPluginTodoist
@@ -106,7 +106,7 @@ static void
 emit_connection_error (void)
 {
   gtd_manager_emit_error_message (gtd_manager_get_default (),
-                                  _("GNOME To Do cannot connect to Todoist due to network issue"),
+                                  _("Endeavour cannot connect to Todoist due to network issue"),
                                   _("Not able to communicate with Todoist. Please check your internet 
connectivity."),
                                   NULL,
@@ -29,7 +29,7 @@
 /**
  * The #GtdPluginTodoist is a class that loads Todoist
- * provider of GNOME To Do.
+ * provider of Endeavour.
  */
 
                                   NULL);